<?php
/**
 * Database Querying, FilmsXpress Querying, Data Retrieval, 
 * Data Modification, Data Formatting
 * 
 * This file is included in inc.lib.html.php. It serves as the
 * database interaction and data formatting layer, void of
 * HTML and content structuring.
 * 
 * @package wwm_lib_php
 * @version 0.1
 * @author Daniel Roestorf <danielroestorf@gmail.com>
 * @copyright West World Media ©2013
 */

 
/**************************************************
 * Error and Exception Handling Functions
 **************************************************/
	
/**
 * Define exception handling here depending on 
 * production or development phase. Usually this is 
 * unimportant because IIS handles it on its own.
 * 
 * @param $e a thrown exception
 */
function handle_exception($e) {
	die("Error: $e");
}

/**************************************************
 * General Functions
 **************************************************/
 	
 	/**
	 * Checks if an ID is numeric
	 * 
	 * redirect to a page if not numeric
	 */
	function check_id($id, $redirect) {
		
		//check the number
		if (!is_numeric($id) || $id == '') {
			header("Location: $redirect");
			die();
		}
	}
	
	/**
	 * redirects requests for old URL movies paths to rewritten url
	 */
	function redirect_old_movie_urls($id, $url_name) {
		
		//get the requested page name
		$request = $_SERVER["REQUEST_URI"];
		if (substr($request, 0, 10) == "/movie?id=") {
			header("Location: /movie/$id/$url_name");
			die();
		}
	}
	
 	/**
	 * Checks if the site config exists
	 * 
	 * @return array $config
	 */
	function get_site_config() {
		
		//get the requested URL and strip www.
		$site_url = str_ireplace("www.","",trim($_SERVER['SERVER_NAME']));
		
		//fetch the config
		$config = @file_get_contents("http://filmsxpress.com/config/$site_url.txt");
		
		//config empty? kill the page
		if ($config == "") {
			die("Website has not been configured properly.");
		} else {
			$config = json_decode($config, TRUE);
			return $config;
		}
	}
	
	/**
	 * Get PHP friendly timezone
	 */
	function get_php_timezone($timezone){	
		$php_timezone = '';
		switch($timezone){
			case 'EST5EDT':
				$php_timezone = 'America/New_York';
				break;
			case 'EST':
				$php_timezone = 'EST';
				break;
			case 'CST6CDT':
				$php_timezone = 'America/Chicago';
				break;
			case 'CST':
				$php_timezone = 'Canada/Saskatchewan';
				break;
			case 'MST7MDT':
				$php_timezone = 'America/Denver';
				break;
			case 'MST':
				$php_timezone = 'America/Phoenix';
				break;
			case 'PST8PDT':
				$php_timezone = 'America/Los_Angeles';
				break;
			case 'PST':
				$php_timezone = 'America/Dawson_Creek';
				break;
			case 'AKST9AKDT':
				$php_timezone = 'America/Anchorage';
				break;
			case 'NZST+12NZDT':
				$php_timezone = 'Pacific/Auckland';
				break;
			case 'AEST':
				$php_timezone = 'Australia/Brisbane';
				break;
			case 'AEST+10AEDT':
				$php_timezone = 'Australia/Sydney';
				break;
			case 'ACST':
				$php_timezone = 'Australia/Darwin';
				break;
			case 'ACST+930ACDT':
				$php_timezone = 'Australia/Adelaide';
				break;
			case 'AWST':
				$php_timezone = 'Australia/Perth';
				break;
			case 'PGT':
				$php_timezone = 'Pacific/Port_Moresby';
				break;
			default:
				break;
		}
		return $php_timezone;
	}
			
	/**
	 * Checks if an remote file exists.
	 * 
	 * @param $url a remote URL
	 * @return boolean true if file exists
	 */
	function isset_external_file($url) {
		$ch = curl_init($url);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, TRUE);
		curl_setopt($ch, CURLOPT_HEADER, TRUE);
		curl_setopt($ch, CURLOPT_NOBODY, TRUE);
		$response = curl_exec($ch);
		
		//No response form remote server
		if ($response === false) {
			curl_close($ch);
			return false;
		}
		
		//check for error codes in response
		$search = array(200, 301, 302, 303, 307);
		if (in_array(curl_getinfo($ch, CURLINFO_HTTP_CODE), $search)) {
			curl_close($ch);
			return true;
		}
		
		//close the connection
		curl_close($ch);
		return false;
	}
	
	/**
	 * Checks what type of device is hitting the site
	 * 
	 * @param $type
	 * @return boolean true if matches regex
	 */
	function check_user_agent ( $type = NULL ) {
	        $user_agent = strtolower ( $_SERVER['HTTP_USER_AGENT'] );
	        if ( $type == 'bot' ) {
	                // matches popular bots
	                if ( preg_match ( "/googlebot|adsbot|yahooseeker|yahoobot|msnbot|watchmouse|pingdom\.com|feedfetcher-google/", $user_agent ) ) {
	                        return true;
	                        // watchmouse|pingdom\.com are "uptime services"
	                }
	        } else if ( $type == 'browser' ) {
	                // matches core browser types
	                if ( preg_match ( "/mozilla\/|opera\//", $user_agent ) ) {
	                        return true;
	                }
	        } else if ( $type == 'mobile' ) {
	                // matches popular mobile devices that have small screens and/or touch inputs
	                // mobile devices have regional trends; some of these will have varying popularity in Europe, Asia, and America
	                // detailed demographics are unknown, and South America, the Pacific Islands, and Africa trends might not be represented, here
	                if ( preg_match ( "/phone|iphone|itouch|ipod|symbian|android|htc_|htc-|palmos|blackberry|opera mini|iemobile|windows ce|nokia|fennec|hiptop|kindle|mot |mot-|webos\/|samsung|sonyericsson|^sie-|nintendo/", $user_agent ) ) {
	                        // these are the most common
	                        return true;
	                } else if ( preg_match ( "/mobile|pda;|avantgo|eudoraweb|minimo|netfront|brew|teleca|lg;|lge |wap;| wap /", $user_agent ) ) {
	                        // these are less common, and might not be worth checking
	                        return true;
	                }
	        }
	        return false;
	}

	
	/**
	 * Checks if browser is on a mobile device
	 * 
	 * @return boolean true if is mobile, false if not
	 */
	function IsMobile() {
		
		//get the user agent string
		$useragent=$_SERVER['HTTP_USER_AGENT'];
		
		//compare UA against regex to determine if mobile
		if(preg_match('/(android|bb\d+|meego).+mobile|avantgo|bada\/|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od)|iris|kindle|lge |maemo|midp|mmp|mobile.+firefox|netfront|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\/|plucker|pocket|psp|series(4|6)0|symbian|treo|up\.(browser|link)|vodafone|wap|windows ce|xda|xiino/i',$useragent)||preg_match('/1207|6310|6590|3gso|4thp|50[1-6]i|770s|802s|a wa|abac|ac(er|oo|s\-)|ai(ko|rn)|al(av|ca|co)|amoi|an(ex|ny|yw)|aptu|ar(ch|go)|as(te|us)|attw|au(di|\-m|r |s )|avan|be(ck|ll|nq)|bi(lb|rd)|bl(ac|az)|br(e|v)w|bumb|bw\-(n|u)|c55\/|capi|ccwa|cdm\-|cell|chtm|cldc|cmd\-|co(mp|nd)|craw|da(it|ll|ng)|dbte|dc\-s|devi|dica|dmob|do(c|p)o|ds(12|\-d)|el(49|ai)|em(l2|ul)|er(ic|k0)|esl8|ez([4-7]0|os|wa|ze)|fetc|fly(\-|_)|g1 u|g560|gene|gf\-5|g\-mo|go(\.w|od)|gr(ad|un)|haie|hcit|hd\-(m|p|t)|hei\-|hi(pt|ta)|hp( i|ip)|hs\-c|ht(c(\-| |_|a|g|p|s|t)|tp)|hu(aw|tc)|i\-(20|go|ma)|i230|iac( |\-|\/)|ibro|idea|ig01|ikom|im1k|inno|ipaq|iris|ja(t|v)a|jbro|jemu|jigs|kddi|keji|kgt( |\/)|klon|kpt |kwc\-|kyo(c|k)|le(no|xi)|lg( g|\/(k|l|u)|50|54|\-[a-w])|libw|lynx|m1\-w|m3ga|m50\/|ma(te|ui|xo)|mc(01|21|ca)|m\-cr|me(rc|ri)|mi(o8|oa|ts)|mmef|mo(01|02|bi|de|do|t(\-| |o|v)|zz)|mt(50|p1|v )|mwbp|mywa|n10[0-2]|n20[2-3]|n30(0|2)|n50(0|2|5)|n7(0(0|1)|10)|ne((c|m)\-|on|tf|wf|wg|wt)|nok(6|i)|nzph|o2im|op(ti|wv)|oran|owg1|p800|pan(a|d|t)|pdxg|pg(13|\-([1-8]|c))|phil|pire|pl(ay|uc)|pn\-2|po(ck|rt|se)|prox|psio|pt\-g|qa\-a|qc(07|12|21|32|60|\-[2-7]|i\-)|qtek|r380|r600|raks|rim9|ro(ve|zo)|s55\/|sa(ge|ma|mm|ms|ny|va)|sc(01|h\-|oo|p\-)|sdk\/|se(c(\-|0|1)|47|mc|nd|ri)|sgh\-|shar|sie(\-|m)|sk\-0|sl(45|id)|sm(al|ar|b3|it|t5)|so(ft|ny)|sp(01|h\-|v\-|v )|sy(01|mb)|t2(18|50)|t6(00|10|18)|ta(gt|lk)|tcl\-|tdg\-|tel(i|m)|tim\-|t\-mo|to(pl|sh)|ts(70|m\-|m3|m5)|tx\-9|up(\.b|g1|si)|utst|v400|v750|veri|vi(rg|te)|vk(40|5[0-3]|\-v)|vm40|voda|vulc|vx(52|53|60|61|70|80|81|83|85|98)|w3c(\-| )|webc|whit|wi(g |nc|nw)|wmlb|wonu|x700|yas\-|your|zeto|zte\-/i',substr($useragent,0,4))) {
			return true;
		} else {
			return false;
		}
	}
	
	/**
	 * Compares the set chain ID to the databased chain ID
	 * 
	 * @param $chain_id
	 * @param $chain_id_dyn
	 * 
	 * Redirects to home page if does not match
	 */
	function verify_house($chain_id, $chain_id_dyn) {
		
		//Go to home page if 2 chain IDs do not match
		if($chain_id != $chain_id_dyn) {
			header("Location: /");
			die();
		}
	}
	
	/**
	 * For use with usort when you want to sort an array by 
	 * the value of name in subarrays.
	 * 
	 * @return number
	 * @example $array = usort($array, 'sort_by_name'); 
	 * @see function 'fxp_get_coming_soon'
	 */
	function sort_by_name($a, $b) {
		return strcmp($a["name"], $b["name"]);
	}
	
	/**
	 * Limits the length of the string to the specified value
	 * and appends a string to show that it is limited.
	 * 
	 * @param $string the string to limit
	 * @param $limit the number of characters to return
	 * @param $append the string to append
	 * @return String
	 */
	function str_limit($string, $limit, $append) {
		
		//If string passes the lenght limit, append the $append text
		if (strlen($string) > $limit) {
			return substr($string, 0, $limit) . $append;
		}
		
		//return the string
		return $string;
	}
	
	/**
	 * Gets an array of showtimes formatted based on 
	 * the format in function 'build_showtime'.
	 * 
	 * @param $house_id
	 * @param $arr a row of showtime data from function 'house_get_showtimes'
	 * @return Array $times a one dimensional array of times
	 * @see function 'build_showtime'
	 * @see function 'house_get_showtimes'
	 */
	function build_dropdown_showtimes($house_id, $arr, $showdate) {
		$times = array();
		$cur_time = date('H:i', strtotime("now")); 
		$cur_date = date('mdY', strtotime("today"));
		$showdate = date('mdY', strtotime("$showdate"));
		$comment = trim($arr["comment"]);
		
		for ($i = 1; $i < 49; $i++) {
			if (strlen(trim($arr["time$i"])) !== 0) {
				
				//we need to figure out if the time is past 'Now'
				$showtime = build_military_time($arr["time$i"], $arr["mer$i"]);
				
				//give the showtime an 'expired' class if it is past 'now'
				if (($showtime < $cur_time) && ($cur_date == $showdate)) {
					//dont show this showtime
				} else {
				
					//fix comment
					if ($comment == "Closed Caption & Descriptive Audio") {
						$comment = " (CC/DVS)";
					}
					
					$times[$showtime]["comment"] = $comment;
					$times[$showtime]["showtime"] = build_showtime_dropdown($arr["time$i"], $arr["mer$i"]);
					$times[$showtime]["url"] = build_showtime_url($house_id, $arr['movie_id'], $arr['showdate'], $arr["time$i"], $arr["mer$i"]);
				}
				
			}
		}
		
		//return the times string
		return $times;
	}
	
	/**
	 * Chaches a remote image to a designated local folder
	 * 
	 * @param $image_url
	 * @param $path
	 *
	 * @return string $local image path
	 */
	 function cache_image($image_url, $path){
		 
		//replace with your cache directory
		$image_path = $path;
		
		//get the name of the file
		$exploded_image_url = explode("/",$image_url);
		$image_filename = end($exploded_image_url);
		$exploded_image_filename = explode(".",$image_filename);
		$extension = end($exploded_image_filename);
		
		//make sure its an image
		if($extension == "gif" || $extension == "jpg" || $extension == "jpeg" || $extension == "png") {
			
			//get the remote image
			$image_to_fetch = file_get_contents($image_url);
			
			//save it
			$local_image_file = fopen($image_path.$image_filename, 'w+');
			chmod($image_path.$image_filename,0755);
			fwrite($local_image_file, $image_to_fetch);
			fclose($local_image_file);
		}
		
		return $image_path.$image_filename;
	}
	
	
	/**
	 * Finds subarray within a array by node value
	 *
	 * @param $array (multi dimensional array with subarrays)
	 * @param $key
	 * @param $value
	 *
	 * return multi dimensional array
	 */
	function search_array($array, $key, $value) {
	    $results = array();
		
		//make sure we are searching an array!
	    if (is_array($array)) {
	    	
	    	//make sure we can find an array with the requested key
	        if (isset($array[$key]) && $array[$key] == $value) {
	            $results[] = $array;
	        }
			
			//make a new array base don found sub arrays
	        foreach ($array as $subarray) {
	            $results = array_merge($results, search_array($subarray, $key, $value));
	        }
	    }
		
		//return the array contaioning that value
	    return $results;
	}
	
	
	/**
	 * Gets an array of showtimes formatted based on 
	 * the format in function 'build_showtime'.
	 * 
	 * @param $house_id
	 * @param $arr a row of showtime data from function 'house_get_showtimes'
	 * @return Array $times a one dimensional array of times
	 * @see function 'build_showtime'
	 * @see function 'house_get_showtimes'
	 */
	function build_showtimes($house_id, $arr, $showdate) {
		$times = array();
		$cur_time = date('H:i', strtotime("now")); 
		$cur_date = date('mdY', strtotime("today"));
		$showdate = date('mdY', strtotime("$showdate"));
		for ($i = 1; $i < 49; $i++) {
			if (strlen(trim($arr["time$i"])) !== 0) {
				
				//we need to figure out if the time is past 'Now'
				$showtime = build_military_time($arr["time$i"], $arr["mer$i"]);
				
				//give teh showtime an 'expired' class if it is past 'now'
				if (($showtime < $cur_time) && ($cur_date == $showdate)) {
					$times[] = '<span class="showtime_expired">'.build_showtime($arr["time$i"], $arr["mer$i"]).'</span>';
				} else {
					$times[] = '<span class="showtime_nolink">'.build_showtime($arr["time$i"], $arr["mer$i"]) . '</span>';
				}
				
			}
		}
		
		//return the times string
		return $times;
	}
	
	/**
	 * Gets a two dimensional array with an associative second index
	 * with 'time' and 'url' keys. This Should only be used if the theater 
	 * uses online ticketing.
	 * 
	 * @param $house_id 
	 * @param $arr a row of showtime data from function: 'house_get_showtimes'
	 * @return Array $times[numeric][key] a two dimensional array
	 * @see function 'house_get_showtimes'
	 * @see function 'build_showtime'
	 * @see function 'build_showtime_url''
	 */
	function build_showtimes_ticketing($house_id, $arr, $showdate, $soldouts) {
		$times = array();
		$cur_time = date('H:i', strtotime("now"));
		$cur_date = date('mdY', strtotime("today"));
		$showdate = date('mdY', strtotime("$showdate"));

		for ($i = 1; $i < 49; $i++) {
			
			//make sure the time field is not blank
			if (strlen(trim($arr["time$i"])) !== 0) {
				
				//format the showtime and ticketing URL
				$time['time'] = build_showtime($arr["time$i"], $arr["mer$i"]);
				$time['url'] = build_showtime_url($house_id, $arr['movie_id'], $arr['showdate'], $arr["time$i"], $arr["mer$i"], $arr['comment']);
				
				//we need to figure out if the time is past 'Now'
				$showtime = build_military_time($arr["time$i"], $arr["mer$i"]);				
				
				//sensory friendly showing - ugly method
				if ($time['time'] == '10:00am' && $arr['movie_id'] == '188417' && $showdate == '09232017'){
					$time['time'] .= " (Sensory Friendly Showing)";
				}
				
				//sensory friendly showing - ugly method-Secondary Movie
				elseif ($time['time'] == '10:00am' && $arr['movie_id'] == '209280' && $showdate == '03182017 '&& ($house_id == '24088' )){
					$time['time'] .= " (Sensory Friendly Showing)";
				}
				
				//add the disabled style if the showdate and current date are the same and we are past the showtime
				if (($showtime < $cur_time) && ($cur_date == $showdate)) {
					$times[] = '<span class="showtime_expired">'.$time['time'].'</span>';
				} else {
					if (isSoldOut($soldouts, $house_id, $arr['movie_id'], $arr['showdate'], $showtime, $arr['comment'])) {
						$times[] = '<span class="showtime_expired">'.$time['time'].'</span>';
					} else {
						$times[] = '<div class="view now"><a href="'.$time['url'].'" target="_blank" class="time">'.$time['time'].'</a>
								<div class="mask"></div>
								<div class="hover"><a href="'.$time['url'].'" target="_blank"  class="info"></a></div>
								</div>';
					}
				}
				
				
			}
		}
		
		//return the times string
		return $times;
	}
	
	/*
	 * isSoldOut - return true if specified showtime is marked soldout in perfs
	 *  $soldouts - array of performances
	 *	$house_id - house
	 *  $movie_id - movie
	 *  $showdate = date
	 *  $showtime - tome
	 *  $comment - filter specific comments
	 *	@return - true or false
	 */	
	function isSoldOut($soldouts, $house_id, $movie_id, $showdate, $showtime, $comment)
	{
		// Nothing is sold out, or don't care
		if ($soldouts == null)
			return(false);
			
		foreach ($soldouts as $soldrow)
		{
			$compdate = date('m/d/Y', strtotime($showdate));
			$dbshowdate = date('m/d/Y', strtotime($soldrow['showdate']));

			/*
			echo "MOVIEID :" . $soldrow['movie_id'] . " - $movie_id<br>\n";
			echo "HOUSEID :" . $soldrow['house_id'] . " - $house_id<br>\n";
			echo "SHOWDATE:" . $soldrow['showdate'] . " - $showdate<br>\n";
			echo "SHOWTIME:" . $soldrow['showtime'] . " - $showtime<br>\n";
			echo "SOLDOUT :" . $soldrow['soldout'] . "<br>\n";
			echo "DBSHOWDATE:" . $dbshowdate . " - $compdate<br><br>\n";
			*/
			
			if ($soldrow['movie_id'] == $movie_id && $soldrow['house_id'] == $house_id && $soldrow['showtime'] == $showtime && $dbshowdate == $compdate)
				return true;				
		}
		
		// Not found, assume not sold out
		return false;	
	}
	
	/**
	 * Gets an array of soldout showtimes for a house and date
	 * 
	 * @param $db
	 * @param $house_id
	 * @param $date YYYY-MM-DD
	 * @return Array $showtimes[numeric]
	 */
	function house_get_perfs_soldout($db, $house_id, $date) {
		$soldOuts = array();
		try {
			$q = $db->prepare("
				DECLARE @house_id varchar(10) SET @house_id = :house_id
				DECLARE @date varchar(10) SET @date = :date
				SELECT house_id, movie_id,  showdate, showtime, showcode, showtext, soldout 
				FROM PerfsLatest WITH (NOLOCK) 
				WHERE soldout=1 and house_id = @house_id AND showdate >= @date
				ORDER BY movie_id ASC
			");
			$q->execute(array(':house_id' => $house_id, ':date' => $date));
			$soldOuts = $q->fetchAll(PDO::FETCH_ASSOC);	
		} catch (PDOException $e) {
			handle_exception($e);
		}

		/*		
		echo "Getting perfs for ";
		print_r($house_id);
		echo " on ";
		print_r($date);
		echo " = ";
		print_r($soldOuts);
		*/
		
		return $soldOuts;
	}
		
	/**
	 * Builds and formats a time for display to the user.
	 * 
	 * @param $time the 'time#' field
	 * @param $mer the 'mer#' field
	 * @return String $time a formatted time
	 */
	function build_showtime($time, $mer) {
		
		//add AM or PM before time conversion
		if ($mer == '1') {
			$time .= "am";
		} else {
			$time .= "pm";
		}
		
		//convert time
		$time = date("g:i", strtotime($time));
		
		//if AM, add am text after showtime
		if ($mer == '1') {
			$time .= "am";
		}
		
		//return the showtime
		return $time;
	}
	
	/**
	 * Builds and formats a time for display to the user.
	 * 
	 * @param $time the 'time#' field
	 * @param $mer the 'mer#' field
	 * @return String $time a formatted time
	 */
	function build_showtime_dropdown($time, $mer) {
		
		//add AM or PM before time conversion
		if ($mer == '1') {
			$time .= " AM";
		} else {
			$time .= " PM";
		}
		
		//convert time
		$time = date("g:i", strtotime($time));
		
		//if AM, add am text after showtime
		if ($mer == '1') {
			$time .= " AM";
		} else {
			$time .= " PM";
		}
		
		//return the showtime
		return $time;
	}
	
	/**
	 * Builds a time formatted in miltary time
	 * 
	 * @param $time the 'time#' field
	 * @param $mer the 'mer#' field
	 * @return String miltary formatted time
	 */
	function build_military_time($time, $mer) {
		
	 	//convert 12:00 AM (midnight) to 24:00 instead of 12:00
		if ($mer === '1' && substr($time,0,2) == "12") {
			$time = str_replace('12:','24:',$time);
		}
		if ($mer === '1' && substr($time,0,2) == "01") {
			$time = str_replace('01:','25:',$time);
		}
		if ($mer === '1' && substr($time,0,2) == "02") {
			$time = str_replace('02:','26:',$time);
		}
		
		//normal time
		if ($mer !== '1') {
			$time = date('G:i', strtotime($time . " pm"));
		}
		
		//return the showtime in military time
		return $time;
	}
	
	/**
	 * Builds a phone number formatted in ###-###-####
	 * 
	 * @param $phone
	 * @return String phone formatted in ###-###-####
	 */
	function build_phone_number($phone) {
		$phone = trim($phone);
		$phone = str_replace(") ", ".",$phone);
		$phone = str_replace("(", "",$phone);
		$phone = str_replace("-", ".", $phone);
		return $phone;
	}
	
	/**
	 * Builds a address string for a theater
	 * 
	 * @param array $arr
	 * @param $seperator
	 * @return String $address
	 */
	function build_house_address($arr, $seperator) {
		return trim($arr["address"]) . ",$seperator " . trim($arr["city"]) . ", " . trim($arr["state"]) . " " . trim($arr["zip"]);
	}
	
	
	/**
	 * Builds a map URL to iframe
	 * 
	 * @param $phone
	 * @param $width (optional)
	 * @param $height (height)
	 * @param $type (google, bing) (optional)
	 * @param $info (yes, no) (optional)
	 *
	 * @return String $map
	 */
	function build_map_url($arr, $width = "455", $height = "220", $type = "google", $info = "no") {
		$lat = trim($arr["lat"]);
		$lon = trim($arr["lon"]);
		$address = build_house_address($arr, "");
		$name = trim($arr["name"]);
		
		/*$map = "http://widgets.westworldmedia.us/maps/index.php?type=$type&width=$width&height=$height&lat=$lat&lon=$lon&name=$name&address=$address&info=$info"; */
		$map = "http://www.paragontheatres.com/maps/?type=$type&width=$width&height=$height&lat=$lat&lon=$lon&name=$name&address=$address&info=$info";
		return $map;
		
	}
	
	/**
	 * Builds a date formatted Y-m-d
	 * 
	 * @param $today
	 * @return String $date formatted Y-m-d
	 */
	function get_current_friday($today) {
		
		//get currnt weekday name
		$cd = date("N", strtotime($today));
		
		//if it's friday	
		if ($cd == 5) {
			$diff = 0;
		} else {
			//if it's staurday
			if ($cd == 6) {
				$diff = -1;
			//its some other day
			} else {
				$diff = -2 - $cd;
			}
		}		   
		
		//convert the above value into a Friday date value
		$date_query = $today . " " . $diff . " days";
		$date = date("Y-m-d", strtotime($date_query));
		
		return $date;
	}
	
	
	/**
	 * Builds a showtime URL for online ticketing.
	 * 
	 * @param $house_id
	 * @param $movie_id
	 * @param $date the 'showtime' field
	 * @param $time the 'time#' field
	 * @param $mer the 'mer#' field
	 * @return String a valid ticketing URL
	 */
	function build_showtime_url($house_id, $movie_id, $date, $time, $mer, $comment) {
		$time = build_military_time($time, $mer);
		$date = date('mdY', strtotime($date));

		// Special versions of film
		$code = "";
		if (strpos($comment, '93.7') !== FALSE)
			$code = '93.7';
		if (strpos($comment, 'Premier') !== FALSE)
			$code = 'Premier';
		if (strpos($comment, 'VIP') !== FALSE)
			$code = 'VIP';
		if (strpos($comment, 'Club') !== FALSE)
			$code = 'Club';
		if (strpos($comment, 'Langley') !== FALSE)
			$code = 'Langley';
		if (strpos($comment, 'Extreme') !== FALSE && strpos($comment, 'Premier') !== FALSE)
			//$code = substr($comment, 0, 32);
			$code = urlencode(trim($comment));
		if (strpos($comment, 'Extreme') !== FALSE && strpos($comment, 'Pepsi') !== FALSE)
			$code = 'Pepsi';
		if (strpos($comment, 'Extreme') !== FALSE && strpos($comment, 'Pepsi') === FALSE && strpos($comment, 'Premier') === FALSE)
				$code = 'Extreme';
		$booking = "http://relay.mvtx.us?house_id=$house_id&movie_id=$movie_id&perfd=$date&perft=$time";
		if ($code != '') {
			$booking .= "&code=$code";
		}
			
		return $booking;
	}
	
	/** 
	 * Builds a string from showtimes. WILL NOT WORK if
	 * used with function: 'build_showtimes_ticketing'.
	 * 
	 * @param $arr an array of showtimes
	 * @param $delimiter the character(s) used to separate the times
	 * @return String a string of showtimes
	 */
	function build_showtimes_string($arr, $delimiter) {
		return implode($delimiter, $arr);
	}
	
	/**
	 * Builds a movie still URL based on a filename.
	 * 
	 * @param $filename
	 * @return String a image URL
	 */
	function build_still_url($filename) {
		return "//www.movienewsletters.net/photos/$filename";
	}
	
	/**
	 * Builds a movie trailer URL but checks if it exists
	 * based on either the 'videos' or 'flv_high' fields.
	 * 
	 * @TODO figure out if it's videos or flv_high.
	 * @param $movie_id
	 * @param $videos the videos or flv_high field
	 * @return String $url a trailer URL if it exists
	 */
	function build_trailer_url($movie_id, $videos) {
		$url = "";
		if (!empty($videos)) {
			$url = "https://m.boxoffice.media/mp4/".$movie_id."_high.mp4";
		}
		return $url;
	}
	
	/**
	 * Builds a movie poster URL based on movie_id and the 
	 * 'hiphotos' field to check if it exists.
	 * 
	 * @param $movie_id
	 * @param $hiphotos the 'hiphotos' field
	 * @return String $url a valid image URL
	 */
	function build_poster_url($movie_id, $hiphotos, $hd = 'no') {
		$url = "//www.movienewsletters.net/photos/000000H1.jpg"; // default
		
		//HD poster?
		if ($hd == 'HD') {
			$extension = "X1.jpg";
		} else {
			$extension = "H1.jpg";
		}
		
		//if poster exists, contruct the image path
		if (!empty($hiphotos)) {
			$url = "//www.movienewsletters.net/photos/".str_pad($movie_id,6,'0',STR_PAD_LEFT).$extension;
		} 
		return $url;
	}

	
	/** 
	 * Builds a string of actor names separated by a delimiter.
	 * 
	 * @param $arr a row of movie data from function: 'movie_get_data'
	 * @param $delimiter the character(s) used to separate the actor names
	 * @return String $str a string of actor names
	 * @see function 'movie_get_data'
	 */
	function build_actors_string($arr, $delimiter, $number) {
		$str = "";
		for ($i = 1; $i <= intval($number); $i++) {
			
			//only 10 actors max
			if ($number <= 10) {
				if ($arr["actor$i"] != '') {
					$str .= trim($arr["actor$i"]) . $delimiter;
				}
			}
		}
		
		return substr($str, 0, strrpos($str, $delimiter));
	}
	
	/** 
	 * Builds a string of genres separated by a delimiter.
	 * 
	 * @param $arr a row of movie data from function: 'movie_get_data'
	 * @param $delimiter the character(s) used to separate the genres
	 * @return String $str a string of genres
	 * @see function 'movie_get_data'
	 */
	function build_genre_string($arr, $delimiter, $number) {
		$str = "";
		for ($i = 1; $i <= intval($number); $i++) {
			
			//only 3 generes max
			if ($number <= 3) {
				if ($i == 1 && $arr["genre"] != '') {
					$str .= $arr["genre"] . $delimiter;
				} else if ($arr["genre$i"] != '') {
					$str .= $arr["genre$i"] . $delimiter;
				}
			}
		}
		
		return substr($str, 0, strrpos($str, $delimiter));
	}
	
	
	/** 
	 * Builds a string of 48 showtime fields and am/pm fields.
	 * 
	 * @return comma seperated string of time fields and bargina fields
	 */
	 function showtime_fields() {
		 
		 $fields = "";
		 
		 //showtimes fields
		 for ($i=1; $i<=48; $i++) {
			 $fields .= "time" . $i . ",";
		 }
		 
		 //AM/PM fields
		  for ($i=1; $i<=48; $i++) {
			 $fields .= "mer" . $i . ",";
		 }
		 
		  //bargain fields
		  for ($i=1; $i<=48; $i++) {
			 $fields .= "bargain" . $i . ",";
		 }
		 
		 //hack off last comma and return string
		 return substr($fields,0,-1);
	 }
	
	/**
	 * Fixes the movie_id by removing the decimal point and 
	 * any trailing values.
	 * 
	 * @param $movie_id
	 * @return String $movie_id
	 */
	function fix_movie_id($movie_id) {
		
		//get rid of decimal points in movie ID
		if (strpos($movie_id, '.') !== false) {
			$movie_id = substr($movie_id, 0, strpos($movie_id, '.'));
		}
		return $movie_id;
	}
	
	/**
	 * Fixes movie names by prepending "The", "An", and "A" 
	 * and removing ", The", ", An", and ", A" respectively.
	 * 
	 * @param $name
	 * @return String $name
	 */
  function fix_movie_name($name) {
    
    //Move The, An, A to front of movie name
    if ((strrpos($name, ", The") > 0) && (strrpos($name, ", The") == (strlen($name) - 5))) {
      return "The " . trim(substr($name, 0, strrpos($name, ", The")));
    } else if ((strrpos($name, ", An") > 0) && (strrpos($name, ", An") == (strlen($name) - 4))) {
      return "An " . trim(substr($name, 0, strrpos($name, ", An")));
    } else if ((strrpos($name, ", A") > 0) && (strrpos($name, ", A") == (strlen($name) - 3))) {
      return "A " . trim(substr($name, 0, strrpos($name, ", A")));
    } else {
      return trim($name);
    }
  }
	
	/**
	 * Adds dashes and converts charcters for friendly URLs
	 * and SEO optimization.
	 * 
	 * @param $name
	 * @return String $name
	 */
	function url_name($name) {
		$name = str_replace("-", "_", $name);
		$name = str_replace("?", "^", $name);
		$name = str_replace(" ", "-", $name);
		$name = str_replace("/", "-", $name);
		$name = str_replace("&", "and", $name);
		$name = str_replace(":", "", $name);
		$name = str_replace(",", "", $name);
		$name = str_replace("+", "-", $name);
		$name = str_replace("'", "", $name);
		return $name;
	}
	
	/**
	 * Fixes the runtime for display by formatting it as '# hr. ## min.'
	 * 
	 * @param $runtime the 'runtime' field
	 * @return String $result a formatted runtime
	 */
	function fix_movie_runtime($runtime) {
		$result = "";
		
		if (!empty($runtime)) {
			
			//if 00 for hour, hard code it
			if (substr($runtime, 0, 2) == "00") {
				$hour = 0;
			} else {
				$hour = (int)substr($runtime, 0, 2);
			}
			
			$min = (int)substr($runtime,3,2);
			
			$result = $hour . " hr. " . $min . " min.";
		} 
		else {
			$result = 'N/A';
		}
		
		return trim($result);
	}		
	/**
	 * Returns a state's full name based on passed in abbreviation
	 * 
	 * @param $state
	 * @return string $state_name
	 */
	 function get_state_name($state) {
		 
		 //array of state names and abbreviations
		 $state_list = array('AL'=>"Alabama", 'AK'=>"Alaska", 'AZ'=>"Arizona", 'AR'=>"Arkansas", 'CA'=>"California", 'CO'=>"Colorado", 'CT'=>"Connecticut", 
		 					 'DE'=>"Delaware", 'DC'=>"District Of Columbia", 'FL'=>"Florida", 'GA'=>"Georgia", 'HI'=>"Hawaii", 'ID'=>"Idaho", 'IL'=>"Illinois", 
							 'IN'=>"Indiana", 'IA'=>"Iowa", 'KS'=>"Kansas", 'KY'=>"Kentucky", 'LA'=>"Louisiana", 'ME'=>"Maine", 'MD'=>"Maryland", 'MA'=>"Massachusetts", 
							 'MI'=>"Michigan", 'MN'=>"Minnesota", 'MS'=>"Mississippi", 'MO'=>"Missouri", 'MT'=>"Montana", 'NE'=>"Nebraska", 'NV'=>"Nevada", 
							 'NH'=>"New Hampshire", 'NJ'=>"New Jersey", 'NM'=>"New Mexico", 'NY'=>"New York", 'NC'=>"North Carolina", 'ND'=>"North Dakota", 
							 'OH'=>"Ohio", 'OK'=>"Oklahoma", 'OR'=>"Oregon", 'PA'=>"Pennsylvania", 'RI'=>"Rhode Island", 'SC'=>"South Carolina", 'SD'=>"South Dakota", 
							 'TN'=>"Tennessee", 'TX'=>"Texas", 'UT'=>"Utah", 'VT'=>"Vermont", 'VA'=>"Virginia", 'WA'=>"Washington", 'WV'=>"West Virginia", 'WI'=>"Wisconsin", 'WY'=>"Wyoming");
		
		//set a variable to the full state name
		$state_name = $state_list[$state];
		
		//clear the array and return the state name
		$state_list = null;
		return $state_name;
	 }
	 
	 /**
	 * Returns a state's full name based on passed in abbreviation
	 * 
	 * @param $state
	 * @return string $state_name
	 */
	 function get_state_list($state_abbr) {
		 
		 //array of state names and abbreviations
		 $state_list = array('AL'=>"Alabama", 'AK'=>"Alaska", 'AZ'=>"Arizona", 'AR'=>"Arkansas", 'CA'=>"California", 'CO'=>"Colorado", 'CT'=>"Connecticut", 
		 					 'DE'=>"Delaware", 'DC'=>"District Of Columbia", 'FL'=>"Florida", 'GA'=>"Georgia", 'HI'=>"Hawaii", 'ID'=>"Idaho", 'IL'=>"Illinois", 
							 'IN'=>"Indiana", 'IA'=>"Iowa", 'KS'=>"Kansas", 'KY'=>"Kentucky", 'LA'=>"Louisiana", 'ME'=>"Maine", 'MD'=>"Maryland", 'MA'=>"Massachusetts", 
							 'MI'=>"Michigan", 'MN'=>"Minnesota", 'MS'=>"Mississippi", 'MO'=>"Missouri", 'MT'=>"Montana", 'NE'=>"Nebraska", 'NV'=>"Nevada", 
							 'NH'=>"New Hampshire", 'NJ'=>"New Jersey", 'NM'=>"New Mexico", 'NY'=>"New York", 'NC'=>"North Carolina", 'ND'=>"North Dakota", 
							 'OH'=>"Ohio", 'OK'=>"Oklahoma", 'OR'=>"Oregon", 'PA'=>"Pennsylvania", 'RI'=>"Rhode Island", 'SC'=>"South Carolina", 'SD'=>"South Dakota", 
							 'TN'=>"Tennessee", 'TX'=>"Texas", 'UT'=>"Utah", 'VT'=>"Vermont", 'VA'=>"Virginia", 'WA'=>"Washington", 'WV'=>"West Virginia", 'WI'=>"Wisconsin", 'WY'=>"Wyoming");
		
		//set a variable to the full state name
		foreach ($state_list as $s){
			$state = $s;
			
			//find out of passed ins tate matches current state
			if (array_search($s, $state_list) == $state_abbr) {
				$selected = "selected";
			} else {
				$selected = "";
			}
			
			//echo the select tag
			echo "<option value='" . array_search($s, $state_list) . "' $selected>$state</option>";
		}
		
		return $state_list;
	 }
	
	/**
	 * Gets the html content from the specified FilmsXpress page.
	 * 
	 * @param $site_id
	 * @param $page_id
	 * @return String the contents of a FilmsXpress page
	 * @see function 'fxp_build_page_url'
	 */
	function fxp_get_page($site_id, $page_id) {
		
		//we want to make sure the file exists and handle the error if it doesn't
		try {
			$html = @file_get_contents(fxp_build_page_url($site_id, $page_id));
		} catch (PDOException $e) {
			$html = $e;
		}
		
		return $html;
	}
	
	/**
	 * Builds a URL for a FilmsXpress page.
	 * 
	 * @param $site_id
	 * @param $page_id
	 * @return String a FilmsXpress page URL
	 */
	function fxp_build_page_url($site_id, $page_id) {
		return "http://www.filmsxpress.com/Content/$site_id/$page_id.txt";
	}
	
	/**
	 * Builds the image URL for a FilmsXpress house.
	 * 
	 * @param $site_id
	 * @param $filename
	 * @return String a FilmsXpress image URL
	 */
	function fxp_build_house_photo_url($site_id, $filename) {
		if ($filename != "") {
			return "//www.filmsxpress.com/images/theatres/$site_id/$filename";
		}
	}
	
	/**
	 * Builds the image URL for a FilmsXpress carousel.
	 * 
	 * @param $site_id
	 * @param $filename
	 * @return String a FilmsXpress image URL
	 */
	function fxp_build_carousel_photo_url($site_id, $filename) {
		if ($filename != "") {
			return "//www.filmsxpress.com/images/Carousel/$site_id/$filename";
		}
	}
	
	/**
	 * Builds the image URL for a FilmsXpress uploaded image.
	 * 
	 * @param $site_id
	 * @param $filename
	 * @return String a FilmsXpress image URL
	 */
	function fxp_build_image_url($site_id, $filename) {
		return "//www.filmsxpress.com/userimages/$site_id/$filename";
	}

	/**
	 * Builds the custom poster URL for a FilmsXpress uploaded poster
	 * 
	 * @param $site_id
	 * @param $filename
	 * @return String a FilmsXpress image URL
	 */
	function fxp_build_poster_url($site_id, $filename) {
		return "//www.filmsxpress.com/images/posters/$site_id/$filename";
	}
	
	/**
	 * Builds the misc image URL for a FilmsXpress uploaded image in the fXp edit movie page.
	 * 
	 * @param $site_id
	 * @param $filename
	 * @return String a FilmsXpress image URL
	 */
	function fxp_build_misc_image_url($site_id, $filename) {
		return "//www.filmsxpress.com/images/misc/$site_id/$filename";
	}
	
	/**
	 * Builds the trailer thumbnail URL from a youtube trailer in the fXp edit movie page.
	 * 
	 * @param $site_id
	 * @param $filename
	 * @return String a FilmsXpress image URL
	 */
	function fxp_build_trailer_thumbnail($trailer, $still = ''){
		if (strpos($trailer, 'youtube') !== false){
			if (strpos($trailer, 'watch?v=')){
				parse_str( parse_url( $trailer, PHP_URL_QUERY ), $link_array );
				$thumb = $link_array['v'];
				return "http://img.youtube.com/vi/$thumb/hqdefault.jpg";
			}
			elseif (strpos($trailer, 'embed/')){
				$thumb = substr(strrchr($trailer, '/'), 1);
				return "http://img.youtube.com/vi/$thumb/hqdefault.jpg";
			}			
		} elseif ($still != '') {
			return $still;
		} else {
			return "/assets/images/icoNoTrailer.png";
			//return "http://www.movienewsletters.net/photos/000000H2.jpg"
		}
	}
	
	/**
	 * Builds the youtube URL from a youtube trailer in the fXp edit movie page.
	 * 
	 * @param $site_id
	 * @param $filename
	 * @return String a FilmsXpress image URL
	 */
	function fxp_build_trailer_url($trailer){
		return $trailer;
		//return "https://www.youtube.com/embed/$video_id";
	}
	
/**************************************************
 * Movie Query Functions
 **************************************************/
	
	/**
	 * Gets an array of important data for the specified movie
	 * 
	 * @param $db PDO Object
	 * @param $movie_id
	 * @return Array $data an associative array of movie data
	 */
	function movie_get_data($db, $movie_id, $site_id) {
		$movie = array();
		try {
			$sql = "SELECT m.movie_id, ISNULL(cs.title,m.name) as name, ISNULL(cs.csRuntime,m.runtime) AS runtime, ISNULL(cs.csMpaa, m.mpaa) as mpaa, 
					m.genre, m.genre2, m.genre3, m.actor1, m.actor2, m.actor3, m.actor4, m.actor5, m.actor6, m.actor7, 
					m.actor8, m.actor9, m.actor10, cs.csActors,ISNULL(cs.csDirector,m.director) as director, cs.custom_text,
					ISNULL(cs.release,m.release) as release, m.hiphotos, m.videos, ISNULL(cs.url,m.url) as url, ISNULL(cs.advisory,m.advisory) AS advisory, 
					ISNULL(cs.csProducer,m.producer) as producer, m.distrib, m.flv_high, ISNULL(cs.csWriter,m.writer) AS writer, cs.posterImage, cs.csTrailer, 
					CASE WHEN cs.synopsis_type = 'Custom' THEN cs.custom_synopsis ELSE RTRIM(r.capsule) END AS capsule,
					cs.release_tbd
					FROM Cinema..Movies m WITH(NOLOCK) 
					LEFT OUTER JOIN Websites..ComingSoon cs WITH(NOLOCK) ON cs.movie_id = m.movie_id AND cs.SiteId = :siteid
					LEFT OUTER JOIN Cinema..Reviews r WITH(NOLOCK) ON m.movie_id = r.movie_id AND r.sid = 
						CASE 
							WHEN cs.synopsis_type = 'none' OR 
								cs.synopsis_type = '' OR 
								cs.synopsis_type IS NULL 
							THEN 'SYSYN' 
							ELSE cs.synopsis_type 
						END 
					WHERE m.movie_id = :movie_id";
			$q = $db->prepare($sql);
			$q->execute(array(':movie_id' => $movie_id, ':siteid' => $site_id));
			$movie = $q->fetch(PDO::FETCH_ASSOC);
		} catch (PDOException $e) {
			handle_exception($e);
		}
		
		return $movie;
	}
	
	/**
	 * Gets a two dimensional array of houses where the specified 
	 * movie is playing on the specified date.
	 * 
	 * @param $db
	 * @param $chain_id
	 * @param $movie_id
	 * @param $date YYYY-MM-DD
	 * @return Array $houses[numeric][key] a two dimensional array
	 */
	function movie_get_houses($db, $site_id, $movie_id, $date) {
		$houses = array();
		try {
			$sql = "SELECT DISTINCT sh.house_id, ISNULL(sh.name,h.name) as name, min(s.showdate) as showdate 
					FROM Websites..SiteHouses sh WITH(NOLOCK) 
					LEFT OUTER JOIN Cinema..Screens s WITH(NOLOCK) ON s.house_id = sh.house_id and s.movie_id = :movie_id and s.showdate >= :date
					LEFT OUTER JOIN Cinema..Houses h WITH(NOLOCK) ON sh.house_id = h.house_id 
					WHERE sh.siteid = :siteid
					GROUP BY sh.house_id, ISNULL(sh.name,h.name) 
					ORDER BY h.name ASC";
			$q = $db->prepare($sql);
			$q->execute(array(':movie_id' => $movie_id, ':siteid' => $site_id, ':date' => $date));
			$houses = $q->fetchAll(PDO::FETCH_ASSOC);
		} catch (PDOException $e) {
			handle_exception($e);
		}
		
		return $houses;
	}
	
	/**
	 * Gets all dates that the specified movie will be playing on at 
	 * the specified house on or after the specified date.
	 * 
	 * @param $db
	 * @param $house_id
	 * @param $movie_id
	 * @param $date YYYY-MM-DD
	 * @return String $result a date in the YYYY-MM-DD format
	 */
	function movie_get_house_showdates($db, $house_id, $movie_id, $date) {
		$dates = array();
		try {
			$q = $db->prepare("
				SELECT distinct showdate FROM Screens WITH(NOLOCK) WHERE house_id = :house_id
				AND movie_id = :movie_id AND showdate >= :date ORDER BY showdate 
			");
			$q->execute(array(':house_id' => $house_id, ':movie_id' => $movie_id, ':date' => $date));
			$dates = $q->fetchAll(PDO::FETCH_ASSOC);
		} catch (PDOException $e) {
			handle_exception($e);
		}
		
		return $dates;
		$r = NULL;
	}
	
	/**
	 * Gets a two dimensional array of houses where the specified 
	 * movie is playing on the specified date.
	 * 
	 * @param $db
	 * @param $chain_id
	 * @param $movie_id
	 * @param $date YYYY-MM-DD
	 * @return Array $houses[numeric][key] a two dimensional array
	 */
	function movie_get_houses_fxp($db, $chain_id, $movie_id, $site_id, $date) {
		$houses = array();
		try {
			$sql = "SELECT DISTINCT h.house_id, ISNULL(sh.Name,h.name) as name, min(s.showdate) as showdate
					FROM Cinema..Screens s WITH(NOLOCK)
					INNER JOIN Cinema..Houses h WITH(NOLOCK) ON s.house_id = h.house_id
					INNER JOIN Websites..SiteHouses sh WITH(NOLOCK) on h.house_id = sh.house_id
					WHERE h.chain_id = :chain_id AND s.movie_id = :movie_id 
					AND s.showdate >= :date 
					GROUP BY h.house_id, ISNULL(sh.Name,h.name) 
					ORDER BY name ASC";
			$q = $db->prepare($sql);
			$q->execute(array(':movie_id' => $movie_id, ':chain_id' => $chain_id, ':date' => $date));
			$houses = $q->fetchAll(PDO::FETCH_ASSOC);
		} catch (PDOException $e) {
			handle_exception($e);
		}
		
		return $houses;
	}
	
	/**
	 * Gets a two dimensional array of houses where the specified 
	 * DBOX movie is playing on the specified date.
	 * 
	 * @param $db
	 * @param $chain_id
	 * @param $movie_id
	 * @param $date YYYY-MM-DD
	 * @return Array $houses[numeric][key] a two dimensional array
	 */
	function movie_get_houses_dbox($db, $chain_id, $movie_id, $date) {
		$houses = array();
		try {
			$sql = "SELECT DISTINCT h.house_id, h.name, s.showdate 
					FROM Cinema..Screens s WITH(NOLOCK)
					INNER JOIN Cinema..Houses h WITH(NOLOCK) ON s.house_id = h.house_id 
					WHERE h.chain_id = :chain_id AND s.movie_id = :movie_id 
					AND s.comment LIKE '%DBOX%' AND s.showdate = :date 
					ORDER BY h.name ASC";
			$q = $db->prepare($sql);
			$q->execute(array(':chain_id' => $chain_id, ':movie_id' => $movie_id, ':date' => $date));
			$houses = $q->fetchAll(PDO::FETCH_ASSOC);
		} catch (PDOException $e) {
			handle_exception($e);
		} 
		
		return $houses;
	}
	
	/**
	 * Gets an array of showtime data for the specified movie at
	 * the specified house on the specified date.
	 * 
	 * @param $db
	 * @param $house_id
	 * @param $movie_id
	 * @param $date YYYY-MM-DD
	 * @return Array $showtimes[key] a array of showtime data
	 */
	function movie_get_showtimes($db, $house_id, $movie_id, $date) {
		$showtimes = array();
		$time_fields = showtime_fields();
		try {
			$sql = "SELECT m.name, m.mpaa, m.runtime, m.actor1, m.actor2, m.actor3, m.actor4, m.hiphotos, 
			        s.comment, s.movie_id, s.showdate, s.allowpass, $time_fields 
					FROM Cinema..Screens s WITH(NOLOCK) 
					INNER JOIN Cinema..Movies m WITH(NOLOCK) ON s.movie_id = m.movie_id 
					WHERE s.house_id = :house_id AND s.movie_id = :movie_id AND s.showdate = :date";
			$q = $db->prepare($sql);
			$q->execute(array(':house_id' => $house_id, ':movie_id' => $movie_id, ':date' => $date));
			$showtimes = $q->fetchAll(PDO::FETCH_ASSOC);
		} catch (PDOException $e) {
			handle_exception($e);
		}
		
		return $showtimes;
	}
	
	/**
	 * Gets an array of showtime data for the specified movie at
	 * at all houses within the chain on the specified date.
	 * 
	 * @param $db
	 * @param $chain_id
	 * @param $movie_id
	 * @param $date YYYY-MM-DD
	 * @return Array $showtimes[key] a array of showtime data
	 */
	function movie_get_showtimes_chain($db, $site_id, $movie_id, $date) {
		$showtimes = array();
		$time_fields = showtime_fields();
		try {
			$sql = "SELECT sh.house_id, s.house_id as show_house_id, ISNULL(sh.name,h.name) as name, s.movie_id, s.showdate, s.comment, s.allowpass, $time_fields
					FROM Websites..SiteHouses sh WITH(NOLOCK) 
					LEFT OUTER JOIN Cinema..Screens s WITH(NOLOCK) ON s.house_id = sh.house_id and s.movie_id = :movie_id AND s.showdate = :date
					JOIN Cinema..Houses h WITH(NOLOCK) ON h.house_id = sh.house_id 
					WHERE sh.siteid = :site_id 
					ORDER BY name ";
			$q = $db->prepare($sql);
			$q->execute(array(':site_id' => $site_id, ':movie_id' => $movie_id, ':date' => $date));
			$showtimes = $q->fetchAll(PDO::FETCH_ASSOC);
		} catch (PDOException $e) {
			handle_exception($e);
		}
		return $showtimes;
	}



	/**
	 * Gets the last date that the specified movie will be playing on at 
	 * the specified house after the specified date.
	 * 
	 * @param $db
	 * @param $house_id
	 * @param $movie_id
	 * @param $date YYYY-MM-DD
	 * @return String $result a date in the YYYY-MM-DD format
	 */
	function movie_get_max_showtime_date($db, $house_id, $movie_id, $date) {
		$result = "";
		try {
			$sql = "SELECT TOP 1 s.showdate 
					FROM Cinema..Screens s WITH(NOLOCK) 
					WHERE s.house_id = :house_id AND s.movie_id = :movie_id AND s.showdate >= :date 
					ORDER BY s.showdate DESC";
			$q = $db->prepare($sql);
			$q->execute(array(':house_id' => $house_id, ':movie_id' => $movie_id, ':date' => $date));
			$r = $q->fetch(PDO::FETCH_ASSOC);
			$result = date('Y-m-d', strtotime($r['showdate']));
		} catch (PDOException $e) {
			handle_exception($e);
		}
		
		return $result;
		$r = NULL;
	}
	
	/**
	 * Gets an array of the versions that the specified movie is available in.
	 * 
	 * @param $db 
	 * @param $movie_id
	 * @param $site_id
	 * @return Array $versions[numeric] an array of movie versions
	 */
	function movie_get_versions($db, $movie_id, $site_id) {
		
		$versions = array();
		try {
			$q = $db->prepare("exec cs_AllMovieVersions_Site :movie_id, :site_id");
			$q->execute(array(':movie_id' => $movie_id, ':site_id' => $site_id));
			$rows = $q->fetchAll(PDO::FETCH_ASSOC);
			foreach ($rows as $row) {
				$name = $row['name'];
				if (strpos($name, "3D") !== false && strpos($name, "IMAX") === false) {
					$versions[] = "3D";
				}
				if (strpos($name, "IMAX") !== false && strpos($name, "3D") === false) {
					$versions[] = "IMAX";
				}
				if (strpos($name, "IMAX") !== false && strpos($name, "3D") !== false) {
					$versions[] = "IMAX 3D";
				}
				if (strpos($name, "DBOX") !== false) {
					$versions[] = "D-BOX";
				}
			}
		} catch (PDOException $e) {
			handle_exception($e);
		}
		
		return $versions;
		$rows = NULL;
	}
	
	/**
	 * Gets one movie still URL for the specified movie by choosing
	 * the second filename returned from the query.
	 * 
	 * @param $db
	 * @param $movie_id
	 * @return String $still a valid image URl
	 * @see function 'build_still_url'
	 */
	function movie_get_still($db, $movie_id) {
		$still = array();
		try {
			$q = $db->prepare("EXEC cs_ListPhotos :movie_id");
			$q->execute(array(':movie_id' => (string)$movie_id));
			$rs = $q->fetchAll(PDO::FETCH_ASSOC);

			if (isset($rs[1])) {
				$still = build_still_url($rs[1]['filename']);
			}
		} catch (PDOException $e) {
			handle_exception($e);
		}
		
		return $still;
		$rs = NULL;
	}
		
	/**
	 * Gets an array of movie still URLs for the specified movie,
	 * ignoring the first filename returned from the query because 
	 * it is a movie poster.
	 * 
	 * @param $db
	 * @param $movie_id
	 * @param $res ('low' or 'high')
	 * @return Array $stills[numeric] an array of valid image URLs
	 * @see function 'build_still_url'
	 */
	function movie_get_stills($db, $movie_id, $res) {
		$stills = array();
		try {
			$q = $db->prepare("EXEC cs_ListPhotos :movie_id");
			$q->execute(array(':movie_id' => $movie_id));
			$rs = $q->fetchAll(PDO::FETCH_ASSOC);
			
			// Ignore first still because it is a movie poster.
			for ($i = 1; $i < count($rs); $i++) {
				$still = build_still_url($rs[$i]['filename']);
		
				//we need to replace the 0(number).jpg with H(number).jpg for high res
				if ($res == 'high') {
					$still = substr_replace($still,'H',-6,1);
				}
				
				//add to the array
				$stills[] = $still;
			}
		} catch (PDOException $e) {
			handle_exception($e);
		}
		
		return $stills;
		$rs = NULL;
	}
	
	/**
	 * Determines if movie is 3D or not
	 * 
	 * @param $movie_name
	 * @return String "3D" if movie is 3D
	 */
	function movie_get_3d($movie_name) {
		
		if (strpos($movie_name, "3D") > 0) {
			$output = "3D";
		} else {
			$output = "";
		}
		return $output;
	}
	
	/**
	 * Determines if movie has certain attributes
	 * 
	 * @param $movie_name
	 * @return String "3D" if movie is 3D
	 */
	function movie_get_attributes($name) {
		
		$output = "";
		
		if (strpos($name, "IMAX") > 0) {
			$output .= "IMAX";
		}
		if (strpos($name, "HFR") > 0) {
			$output .= "HFR";
		}
		if (strpos($name, "3D") > 0) {
			$space = "";
			if ($output != "") {
				$space = " ";
			}
			$output .= $space . "3D";
		}
	
		return $output;
	}
	
/**************************************************
 * House Query Functions
 **************************************************/
	
	/**
	 * Gets an associative array of important data for the specified house with 
	 * 
	 * @param $db
	 * @param $house_id
	 *
	 * @return Array $house[key] an array of house data
	 */
	function house_get_data($db, $house_id) {
		$house = array();
		try {
			$sql = "SELECT * 
					FROM Cinema..Houses h WITH(NOLOCK) 
					WHERE h.house_id = :house_id";
			$q = $db->prepare($sql);
			$q->execute(array(':house_id' => $house_id));
			$house = $q->fetch(PDO::FETCH_ASSOC);
		} catch (PDOException $e) {
			handle_exception($e);
		}
		
		return $house;
	}
	
	/**
	 * Gets an associative array of important data for the specified house with 
	 * 
	 * @param $db
	 * @param $house_id
	 * @param $site_id
	 *
	 * @return Array $house[key] an array of house data
	 */
	function house_get_data_fxp($db, $house_id, $site_id) {
		$house = array();
		try {
			$sql = "SELECT ISNULL(sh.name,ch.name) as name, ISNULL(sh.address,ch.address1) as address, 
					ISNULL(sh.locator,ch.location) as locator, ISNULL(sh.phone,ch.movieline) as movieline,
					ISNULL(sh.phone,ch.movieline) as movieline, ISNULL(sh.phoneoffice,ch.phone1) as office_phone, 
					ch.ticketing, ch.phone1, ch.city, ch.state, ch.zip, ch.chain_id, sh.tagline, sh.siteid, 
					sh.PhotoUrl, sh.email, ch.lat, ch.lon, sh.message_page, sh.amenities, sh.policies, sh.timezone, sh.posType, sh.hide_showtimes   
					FROM Cinema..Houses ch WITH(NOLOCK)
					INNER JOIN Websites..SiteHouses sh WITH(NOLOCK) ON ch.house_id = sh.house_id and sh.siteid = :site_id
					where ch.house_id = :house_id";
			$q = $db->prepare($sql);
			$q->execute(array(':site_id' => $site_id,':house_id' => $house_id));
			$house = $q->fetch(PDO::FETCH_ASSOC);
		} catch (PDOException $e) {
			handle_exception($e);
		}
		
		return $house;
	}

	
	/**
	 * Gets an associative array of prices for the specified house with 
	 * 
	 * @param $db
	 * @param $house_id
	 *
	 * @return Array $prices[key] an array of price data
	 */
	function house_get_prices($db, $house_id) {
		$prices = array();
		try {
			$sql = "SELECT * 
					FROM Websites..Prices p WITH(NOLOCK) 
					WHERE p.house_id = :house_id
					ORDER BY p.price_id";
			$q = $db->prepare($sql);
			$q->execute(array(':house_id' => $house_id));
			$prices = $q->fetchAll(PDO::FETCH_ASSOC);
		} catch (PDOException $e) {
			handle_exception($e);
		}
		
		return $prices;
	}
	
	/**
	 * Gets an array of showdates for the specified house
	 * on the specified date. 
	 * 
	 * @param $db
	 * @param $house_id
	 * @param $date YYYY-MM-DD
	 * @return Array $dates[numeric]
	 */
	function house_get_showdates($db, $house_id, $date) {
		$i = 0;
		$showdates = array();
	
		try {
			$sql = "SELECT DISTINCT s.showdate 
					FROM Cinema..Screens s WITH(NOLOCK) 
					WHERE s.house_id = :house_id AND s.showdate >= :date 
					ORDER BY s.showdate ASC";
			$q = $db->prepare($sql);
			$q->execute(array(':house_id' => $house_id, ':date' => $date));
			$dates = $q->fetchAll(PDO::FETCH_ASSOC);
			
			//loop through array
			if (!empty($dates)) {
				foreach ($dates as $d) {
					
					//get the showdate
					$showdate = date('n/j/Y', strtotime($d["showdate"]));
					
					//save the first date
					if ($i == 0) {
						$showdates["start_date"] = $showdate;
					}
					
					//add to the showdates sub array
					$showdates["showdates"][$i] = $showdate;
					$i++;
				}
			} else {
				$showdates["start_date"] = date('n/j/Y');
				$showdates["showdates"][0] = date('n/j/Y');
			}
		} catch (PDOException $e) {
			handle_exception($e);
		}
		
		return $showdates;
	}
	
	/**
	 * Gets an array of showdates for the specified house and movie
	 * on the specified date. 
	 * 
	 * @param $db
	 * @param $house_id
	 * @param $movie_id
	 * @param $date YYYY-MM-DD
	 *
	 * @return Array $dates[numeric]
	 */
	function house_get_movie_showdates($db, $house_id, $movie_id, $date) {
		$dates = array();
		try {
			$sql = "SELECT DISTINCT s.showdate 
					FROM Cinema..Screens s WITH(NOLOCK) 
					WHERE s.house_id = :house_id AND s.showdate >= :date and m.movie_id = :movie_id 
					ORDER BY s.showdate ASC";
			$q = $db->prepare($sql);
			$q->execute(array(':house_id' => $house_id, ':date' => $date, ':movie_id' => $movie_id));
			$dates = $q->fetchAll(PDO::FETCH_ASSOC);	
			
			//loop through results and convert dates to Y-m-d format
			for ($i = 0; $i < count($dates); $i++) {
				$dates[$i] = date('Y-m-d', strtotime($dates[$i]['showdate']));
			}
		} catch (PDOException $e) {
			handle_exception($e);
		}
		
		return $dates;
	}
	
	/**
	 * Gets an array of showdates for the specified chain and movie
	 * on the specified date. 
	 * 
	 * @param $db
	 * @param $site_id
	 * @param $movie_id
	 * @param $date YYYY-MM-DD
	 *
	 * @return Array $dates[numeric]
	 */
	function chain_get_movie_showdates($db, $site_id, $movie_id, $date) {
		$dates = array();
		$showdates = array();
		$i = 0;
		
		try {
			$sql = "SELECT distinct showdate 
				    FROM Screens WITH(NOLOCK) WHERE house_id in
				   		(SELECT house_id FROM Websites..SiteHouses WITH(NOLOCK)
				   		WHERE siteid = :siteid)
				    and showdate >= :showdate and movie_id = :movie_id 
				    ORDER BY showdate";
			$q = $db->prepare($sql);
			$q->execute(array(':siteid' => $site_id, ':showdate' => $date, ':movie_id' => $movie_id));
			$dates = $q->fetchAll(PDO::FETCH_ASSOC);

			//loop through array
			if (!empty($dates)) {
				foreach ($dates as $d) {
					
					//get the showdate
					$showdate = date('n/j/Y', strtotime($d["showdate"]));
					
					//save the first date
					if ($i == 0) {
						$showdates["start_date"] = $showdate;
					}
					
					//add to the showdates sub array
					$showdates["showdates"][$i] = $showdate;
					$i++;
				}
			} else {
				$showdates["start_date"] = date('n/j/Y');
				$showdates["showdates"][0] = date('n/j/Y');
			}
			$dates = NULL;	
		} catch (PDOException $e) {
			handle_exception($e);
		}
		
		return $showdates;
	}
	
	/**
	 * Gets an array of showdates for the specified house from the Perfs table
	 * on the specified date. Used for theatres who's showtime data we don't manage.
	 * 
	 * @param $db
	 * @param $house_id
	 * @param $date YYYY-MM-DD
	 *
	 * @return Array $dates[numeric]
	 */
	function house_get_perfs_showdates($db, $house_id, $date) {
		$dates = array();
		try {
			$sql = "SELECT DISTINCT p.showdate 
					FROM Cinema..Perfs p WITH(NOLOCK) 
					WHERE p.house_id = :house_id AND p.showdate >= :date 
					ORDER BY p.showdate ASC";
			$q = $db->prepare($sql);
			$q->execute(array(':house_id' => $house_id, ':date' => $date));
			$dates = $q->fetchAll(PDO::FETCH_ASSOC);
			
			//loop through results and convert dates to Y-m-d format	
			for ($i = 0; $i < count($dates); $i++) {
				$dates[$i] = date('Y-m-d', strtotime($dates[$i]['showdate']));
			}
		} catch (PDOException $e) {
			handle_exception($e);
		}
		
		return $dates;
	}
	
	/**
	 * Gets a two dimensional array of showtime and certain movie data for the specified
	 * house on the specified date. Extra whitespace is trimmed from certain values.
	 * 
	 * @param $db
	 * @param $house_id
	 * @param $date YYYY-MM-DD
	 *
	 * @return Array $showtimes[numeric][key] a two dimensional array
	 */
	function house_get_showtimes($db, $site_id, $house_id, $date) {
		$showtimes = array();
		$time_fields = showtime_fields();
		try {
			$sql = "SELECT s.movie_id, ISNULL(cs.title,m.name) as name, s.showdate, isnull(cs.release, m.release) as release, m.release AS raw_release,
					ISNULL(cs.csMpaa,m.mpaa) as mpaa, ISNULL(cs.csRuntime, m.runtime) as runtime, 
					m.actor1, m.actor2, m.actor3, m.actor4, m.actor5, m.genre, m.genre2, m.genre3, 
					s.comment, m.hiphotos, m.flv_high, s.allowpass, cs.posterImage, $time_fields 
					FROM Cinema..Screens s WITH(NOLOCK) 
					INNER JOIN Cinema..Movies m WITH(NOLOCK) ON s.movie_id = m.movie_id
					LEFT OUTER JOIN Websites..ComingSoon cs WITH(NOLOCK) ON cs.SiteId = :SiteId AND cs.movie_id = s.movie_id
					WHERE s.house_id = :house_id AND s.showdate = :date 
					ORDER BY isnull(cs.release, m.release) desc, replace(m.name, ', The', ''), s.comment desc" ;
			$q = $db->prepare($sql);
			$q->execute(array(':SiteId' => $site_id, ':house_id' => $house_id, ':date' => $date));
			$showtimes = $q->fetchAll(PDO::FETCH_ASSOC);
		} catch (PDOException $e) {
			handle_exception($e);
		}
		
		return $showtimes;
	}

	
	/**
	 * Gets a two dimensional array of showtime and certain movie data for the specified
	 * house on the specified date. Extra whitespace is trimmed from certain values.
	 * This function merges all child movies into the parent
	 * 
	 * @param $db
	 * @param $house_id
	 * @param $date YYYY-MM-DD
	 *
	 * @return Array $movies[parent_id][key] a two dimensional array
	 */
	function house_get_showtimes_parent($db, $house_id, $date) {
		
		//setup some intial variables
		$movies = array();
		$parent_id_old = "";
		$movie_id_old = "";
		$i = 0;
	
		try {
			$sql = "SELECT m.movie_id, m.parent_id, m.actor1,m.actor2, m.actor3, m.actor4, m.actor5, 
					m.name, m.release, m.director, m.mpaa, m.runtime, s.house_id, s.showdate, 
					s.comment, m.genre, m.genre2, m.genre3, $time_fields
					FROM Cinema..Screens s WITH(NOLOCK), Cinema..Movies m WITH(NOLOCK)
					WHERE s.house_id = :house_id AND s.showdate = :date AND s.movie_id = m.movie_id 
					ORDER BY m.release DESC, replace(m.name, ', The', ''), 
					CASE WHEN s.comment = '' THEN 0 ELSE 1 end";
			$q = $db->prepare($sql);
			$q->execute(array(':house_id' => $house_id, ':date' => $date));
			$rows = $q->fetchAll(PDO::FETCH_ASSOC);
		} catch(PDOException $e) {
			die("Error Connecting to Database:" . $e);
		}
		
		//loop through the results and mke a custom $movies array
		foreach ($rows as $m) {
			
			$movie_id = fix_movie_id($m["movie_id"]);
			$ticket_id = fix_movie_id($m["movie_id"]);
			$parent_id = fix_movie_id($m["parent_id"]);
			$comment = "*".trim($m["comment"]);
						
			//start an array key with the movie id
			//But not if this is the same movie or the parent is the same as the last movie
			if ($movie_id_old != $movie_id && $movie_id_old != $parent_id) {
				$i = 0;
				
				//print out the info only if this is a standalone sub version
				$movies[$movie_id]["id"] = $m["movie_id"];
				$movies[$movie_id]["name"] = fix_movie_name($m["name"]);
				$movies[$movie_id]["mpaa"] = trim($m["mpaa"]);
				$movies[$movie_id]["actors"] = build_actors_string($m, ', ', 5);
				$movies[$movie_id]["runtime"] = fix_movie_runtime($m["runtime"]);
				$movies[$movie_id]["synopsis"] = trim($m["capsule"]);
				$movies[$movie_id]["director"] = trim($m["director"]);
			}
			
			///change the movie ID to the parent ID if it matches the old movie id
			if ($parent_id == $movie_id_old) {
				$movie_id = $parent_id;
			} else {
				$movie_id = $movie_id;
			}
			
			//fill in showtimes array
			if ($print) {
				$movies[$movie_id]["showtimes"][$i] = array('times' => getTimesNew($m), 'comment' => join_comments($m), 'ticket_id' => $ticket_id);
				$i++;
			}
			
			$movie_id_old = $movie_id;
			$parent_id_old = $parent_id;
		}
		
		//return teh array
		return $movies;
	}

	
	/**
	 * Gets a two dimensional array of all movies that are playing 
	 * at the specified house on the specified date  
	 * 
	 * @param $db
	 * @param $house_id
	 * @param $date YYYY-MM-DD
	 *
	 * @return Array $movies[numeric][key] a two dimensional array
	 */
	function house_get_now_playing($db, $house_id, $date) {
		$movies = array();
		try {
			$sql = "SELECT DISTINCT m.movie_id, m.name, m.hiphotos, 
					attribute = case when charindex('DBOX', comment)>0 then 'DBOX ' else '' end 
					FROM Cinema..Screens s WITH(NOLOCK) 
					INNER JOIN Cinema..Movies m WITH(NOLOCK) ON s.movie_id = m.movie_id 
					WHERE s.house_id = :house_id AND s.showdate = :date 
					ORDER BY m.name";
			$q = $db->prepare($sql);
			$q->execute(array(':house_id' => $house_id, ':date' => $date));
			$movies = $q->fetchAll(PDO::FETCH_ASSOC);
		} catch (PDOException $e) {
			handle_exception($e);
		}
		
		return $movies;
	}
	
	
	/**
	 * Gets a two dimensional array of all 3D movies that are 
	 * playing at the specified house.
	 * 
	 * @param $db
	 * @param $house_id
	 * @param $date YYYY-MM-DD
	 *
	 * @return Array $movies[numeric][key] a two dimensional array
	 */
	function house_get_now_playing_3D($db, $house_id, $date) {
		$movies = array();
		try {
			$sql = "SELECT DISTINCT m.movie_id, m.name, m.hiphotos 
					FROM Cinema..Screens s WITH(NOLOCK) 
					INNER JOIN Cinema..Movies m WITH(NOLOCK) ON s.movie_id = m.movie_id 
					WHERE s.house_id = :house_id AND s.showdate = :date AND m.name LIKE '%3D%' 
					ORDER BY m.name";
			$q = $db->prepare($sql);
			$q->execute(array(':house_id' => $house_id, ':date' => $date));
			$movies = $q->fetchAll(PDO::FETCH_ASSOC);
		} catch (PDOException $e) {
			handle_exception($e);
		}
		
		return $movies;
	}
	
	/**
	 * Gets a two dimensional array of all movies that are 
	 * playing at the specified house starting today.
	 * 
	 * @param $db
	 * @param $house_id
	 * @param $date YYYY-MM-DD
	 *
	 * @return Array $movies[numeric][key] a two dimensional array
	 */
	function house_get_now_playing_all($db, $house_id, $date) {
		$movies = array();
		try {
			$sql = "SELECT DISTINCT m.movie_id, m.name 
					FROM Cinema..Screens s WITH(NOLOCK) 
					INNER JOIN Cinema..Movies m WITH(NOLOCK) ON s.movie_id = m.movie_id 
					WHERE s.house_id = :house_id AND s.showdate >= :date 
					ORDER BY m.name";
			$q = $db->prepare($sql);
			$q->execute(array(':house_id' => $house_id, ':date' => $date));
			$movies = $q->fetchAll(PDO::FETCH_ASSOC);
		} catch (PDOException $e) {
			handle_exception($e);
		}
		
		return $movies;
	}
	
	/**
	 * Gets an associative array of important data for the specified house with 
	 * 
	 * @param $db
	 * @param $house_id
	 * @param $site_id
	 *
	 * @return Array $house[key] an array of house data
	 */
	function get_site_house_timezone($db, $house_id, $site_id) {
		$timezone = array();

		try {
			$sql = "SELECT timezone
					FROM Websites..SiteHouses WITH(NOLOCK)
					WHERE SiteId = :SiteId AND house_id = :house_id";
			$q = $db->prepare($sql);
			$q->execute(array(':SiteId' => $site_id,':house_id' => $house_id));
			$timezone = $q->fetch(PDO::FETCH_ASSOC);
		} catch (PDOException $e) {
			handle_exception($e);
		}
		
		return get_php_timezone($timezone['timezone']);
	}

/**************************************************
 * Chain Query Functions
 **************************************************/

	/**
	 * Gets a two dimensional array of houses in the specified
	 * chain and important data for each.
	 * 
	 * @param $db
	 * @param $chain_id
	 * @param $site_id (can be blank)
	 * @return Array $houses[numeric][key] a two dimensional array
	 */
function chain_get_houses($db, $chain_id, $site_id) {
		$houses = array();
		try {
			if ($site_id == '') {
				$sql = "SELECT h.house_id, h.name, h.address1, h.address2, h.city, h.state, h.zip, h.phone1, 
						h.movieline, h.digital, h.dolby, h.numscreens, h.seating, h.lat, h.lon 
						FROM Cinema..Houses WITH(NOLOCK) 
						WHERE h.chain_id = :chain_id
						ORDER BY h.state, h.name ";
				$q = $db->prepare($sql);
				$q->execute(array(':chain_id' => $chain_id));
			} else {
				$sql = "SELECT h.house_id, ISNULL(sh.name,h.name) as name, ISNULL(sh.address,h.address1) AS address, 
						h.address2, ISNULL(sh.city,h.city) AS city, ISNULL(sh.state,h.state) AS state, h.zip, 
						ISNULL(sh.phone,h.phone1) AS phone, ISNULL(sh.Phone,h.movieline) as movieline, h.digital, 
						h.dolby, h.numscreens, h.seating, h.lat, h.lon, sh.photourl 
						FROM Websites..SiteHouses sh WITH(NOLOCK)
						INNER JOIN Cinema..Houses h WITH(NOLOCK) ON h.house_id = sh.house_id
						WHERE sh.SiteId = :site_id
						ORDER BY state, name ";
				$q = $db->prepare($sql);
				$q->execute(array(':site_id' => $site_id));
			}
			$houses = $q->fetchAll(PDO::FETCH_ASSOC);
		} catch (PDOException $e) {
			handle_exception($e);
		}
		
		return $houses;
	}
		
	
	/**
	 * Gets a two dimensional array of houses in the specified
	 * chain and important data for each.
	 * 
	 * @param $db
	 * @param $chain_id
	 * @param $site_id
	 *
	 * @return Array $houses[numeric][key] a two dimensional array
	 */
	function chain_get_fxp_houses($db, $chain_id, $site_id) {
		$houses = array();
		try {
			$sql = "SELECT h.house_id, ISNULL(sh.name,h.name) as name, ISNULL(sh.address,h.address1) AS address, 
					ch.address2, ISNULL(sh.city,h.city) AS city, ISNULL(sh.state,h.state) AS state, h.zip, 
					ISNULL(sh.phone,h.phone1) AS phone, ISNULL(sh.Phone,h.movieline) as movieline, h.digital, 
					h.dolby, h.numscreens, h.seating, h.lat, h.lon 
					FROM Cinema..Houses h WITH(NOLOCK)
					INNER JOIN Websites..SiteHouses sh WITH(NOLOCK) ON h.house_id = sh.house_id AND sh.siteid = :site_id 
					WHERE h.chain_id = :chain_id 
					ORDER BY name ";
			$q = $db->prepare($sql);
			$q->execute(array(':site_id' => $site_id, ':chain_id' => $chain_id));
			$houses = $q->fetchAll(PDO::FETCH_ASSOC);
		} catch (PDOException $e) {
			handle_exception($e);
		}
		
		return $houses;
	}
	
	/**
	 * Gets a two dimensional array of houses in the specified 
	 * chain that are playing DBOX movies on the specified date.
	 * 
	 * @param $db
	 * @param $chain_id
	 * @param $date YYYY-MM-DD
	 *
	 * @return Array $houses[numeric][key] a two dimensional array
	 */
	function chain_get_houses_dbox($db, $chain_id, $date) {
		$houses = array();
		try {
			$sql = "SELECT DISTINCT h.house_id, h.name 
					FROM Cinema..Houses h WITH(NOLOCK), Cinema..Screens s WITH(NOLOCK) 
					WHERE h.house_id = s.house_id AND s.comment LIKE '%DBOX%' 
					AND h.chain_id = :chain_id AND s.showdate = :date 
					ORDER BY h.name ASC";
			$q = $db->prepare($sql);
			$q->execute(array(':chain_id' => $chain_id, ':date' => $date));
			$houses = $q->fetchAll(PDO::FETCH_ASSOC);
		} catch (PDOException $e) {
			handle_exception($e);
		}
		
		return $houses;
	}
		
	/**
	 * Gets a two dimensional array of movies that are playing
	 * in the specified site on the specified date.
	 * 
	 * @param $db
	 * @param $site_id
	 * @param $date YYYY-MM-DD
	 *
	 * @return Array $movies[numeric][key] a two dimensional array
	 */
	function chain_get_now_playing($db, $site_id, $date) {
		$movies = array();
		try {
			$sql = "SELECT DISTINCT m.movie_id, isnull(cs.title,m.name) as name, m.hiphotos, m.videos, isnull(cs.release,m.release) as release, cs.posterImage, 
					ISNULL(cs.csMpaa,m.mpaa) as mpaa, m.genre, m.genre2, m.genre3, m.runtime, 
					CASE WHEN m.parent_id = '0' THEN m.movie_id ELSE m.parent_id END AS parent_id,
					CASE WHEN cs.synopsis_type = 'Custom' THEN cs.custom_synopsis ELSE RTRIM(r.capsule) END AS capsule 
					FROM Websites..SiteHouses sh WITH(NOLOCK)
					INNER JOIN Cinema..Screens s WITH(NOLOCK) ON sh.house_id = s.house_id 
					INNER JOIN Cinema..Movies m WITH(NOLOCK) ON s.movie_id = m.movie_id AND m.parent_id = 0
					LEFT OUTER JOIN Websites..ComingSoon cs WITH(NOLOCK) ON cs.SiteId = sh.SiteId AND cs.movie_id = m.movie_id
					LEFT OUTER JOIN Cinema..Reviews r WITH(NOLOCK) ON m.movie_id = r.movie_id AND r.sid = 
						CASE 
							WHEN cs.synopsis_type = 'none' OR 
								cs.synopsis_type = '' OR 
								cs.synopsis_type IS NULL 
							THEN 'SYSYN' 
							ELSE cs.synopsis_type 
						END 
					WHERE sh.siteid = :site_id AND s.showdate = :date 
					ORDER BY m.release desc, m.name";
			$q = $db->prepare($sql);
			$q->execute(array(':site_id' => $site_id, ':date' => $date));
			$movies = $q->fetchAll(PDO::FETCH_ASSOC);
		} catch (PDOException $e) {
			handle_exception($e);
		}
		
		return $movies;
	}
	
	/**
	 * Gets a two dimensional array of movies that are playing
	 * in the specified chain that are not playing today (advance showings).
	 * 
	 * @param $db
	 * @param $site_id
	 *
	 * @return Array $movies[numeric][key] a two dimensional array
	 */
	function chain_get_advance($db, $site_id) {
		$movies = array();
		try {
			$sql = "SELECT DISTINCT m.movie_id, m.mpaa, m.runtime, m.videos, m.hiphotos, m.name 
					FROM  Cinema..Movies m WITH(NOLOCK), Cinema..Screens s WITH(NOLOCK), 
					Cinema..Houses h WITH(NOLOCK), Websites..SiteHouses sh WITH(NOLOCK)
					WHERE m.movie_id = s.movie_id
					and h.house_id = s.house_id and h.house_id = sh.house_id and m.hiphotos = 1
					and sh.siteId = :siteid and s.showdate > Convert(varchar(20), getdate(), 112) 
					and m.release > Convert(varchar(20), getdate(), 112)
					and m.movie_id not in 
						(SELECT DISTINCT movie_id 
						FROM Cinema..Screens s WITH(NOLOCK), Websites..SiteHouses sh WITH(NOLOCK)
						WHERE s.house_id = sh.house_id and sh.siteId = :siteid2 and s.showdate = Convert(varchar(20), getdate(), 112) ) 
					ORDER BY m.name";
			$q = $db->prepare($sql);
			$q->execute(array(':siteid' => $site_id, ':siteid2' => $site_id));
			$movies = $q->fetchAll(PDO::FETCH_ASSOC);
		} catch (PDOException $e) {
			handle_exception($e);
		}
		
		return $movies;
	}

	
	/**
	 * Gets a two dimensional array of all DBOX movies that are 
	 * playing in the specified chain on the specified date.
	 * 
	 * @param $db
	 * @param $chain_id
	 * @param $date YYYY-MM-DD
	 * @return Array $movies[numeric][key] a two dimensional array
	 */
	function chain_get_now_playing_dbox($db, $chain_id, $date) {
		$movies = array();
		try {
			$q = $db->prepare("
				SELECT DISTINCT m.movie_id,RTRIM(m.name) AS name,m.release,m.hiphotos
				FROM Houses h WITH(NOLOCK) 
				INNER JOIN Screens s WITH(NOLOCK) ON h.house_id = s.house_id 
				INNER JOIN Movies m WITH(NOLOCK) ON s.movie_id = m.movie_id 
				WHERE (h.chain_id = :chain_id) AND s.showdate = :date AND (s.comment LIKE '%DBOX%' OR s.comment LIKE '%D-BOX%') 
				ORDER BY name ASC
			");
			$q->execute(array(':chain_id' => $chain_id, ':date' => $date));
			$movies = $q->fetchAll(PDO::FETCH_ASSOC);
		} catch (PDOException $e) {
			handle_exception($e);
		}
		return $movies;
	}

/**************************************************
 * Sitemap Query Functions
 **************************************************/
 	
 	/**
	 * Gets a two dimensional array of all movies 
	 * playing at houses in a website
	 * 
	 * @param $db
	 * @param $site_id
	 * @return Array $movies[numeric][key] a two dimensional array
	 */
	function sitemap_get_movies($db, $site_id) {
		$movies = array();
		try {
			$sql = "SELECT DISTINCT m.movie_id, m.name, m.hiphotos, m.flv_high 
					FROM Cinema..Movies m WITH(NOLOCK), Cinema..Screens s WITH(NOLOCK), Websites..SiteHouses sh WITH(NOLOCK) 
					WHERE sh.house_id = s.house_id and sh.siteid = :siteid and m.movie_id = s.movie_id and s.showdate >= :date
					and m.movie_id <> 1";
			$q = $db->prepare($sql);
			$q->execute(array(':siteid' => $site_id, ':date' => date('n/j/Y')));
			$movies = $q->fetchAll(PDO::FETCH_ASSOC);
		} catch (PDOException $e) {
			handle_exception($e);
		}
		return $movies;
	}

/**************************************************
 * Search Query Functions
 **************************************************/
 
 	/**
	 * Gets a two dimensional array of all movies 
	 * and theaters playing at or a part of a website
	 * 
	 * @param $db
	 * @param $site_id
	 * @param $search
	 *
	 * @return Array $movies[numeric][key] a two dimensional array
	 */
	function search_movies_and_houses($db, $site_id, $search) {
		$results = array();
		
		//adjust the search variable to remove unwanted characters
		$search = str_replace("%20", "", $search);
		if (strtolower(substr($search, 0, 4)) == 'the ') {
			$search = substr($search, 4);
		}
		
		try {
			$sql = "SELECT DISTINCT m.movie_id as id, m.name, category = 'movies'
					FROM Cinema..Movies m WITH(NOLOCK)
					WHERE
						((m.movie_id in
							(SELECT movie_id FROM Cinema..Screens s WITH(NOLOCK)
							 INNER JOIN Websites..SiteHouses sh ON s.house_id = sh.house_id and sh.siteid = :siteid)
						) or (m.movie_id in
							 (SELECT movie_id FROM Websites..ComingSoon cs WITH(NOLOCK) WHERE cs.siteid = :siteid2))
						 )
					and m.name like '%$search%'
					UNION ALL
					SELECT DISTINCT sh.house_id as id, ISNULL(sh.name,h.name) as name, category = 'theaters'
					FROM Websites..SiteHouses sh WITH(NOLOCK), Cinema..Houses h WITH(NOLOCK)
					WHERE sh.house_id = h.house_id and sh.siteid = :siteid3
					and (ISNULL(sh.name,h.name) like '%$search%' or ISNULL(sh.city,h.city) like '%$search%' or h.zip like '%$search%' )
					ORDER BY category, name";
			$q = $db->prepare($sql);
			$q->execute(array(':siteid' => $site_id, ':siteid2' => $site_id, ':siteid3' => $site_id));
			$results = $q->fetchAll(PDO::FETCH_ASSOC);
		} catch (PDOException $e) {
			handle_exception($e);
		}
		return $results;
	}
	
	
/**************************************************
 * FilmsXpress Query Functions
 **************************************************/
 	
 	
 	/**
	 * Gets a two dimensional array of all movies that are 
	 * playing at the specified chain/site starting today.
	 * 
	 * @param $db
	 * @param $site_id
	 * @param $date YYYY-MM-DD
	 *
	 * @return Array $movies[numeric][key] a two dimensional array
	 */
	function fxp_get_all_movies($db, $site_id, $date) {
		$movies = array();
		try {
			$sql = "SELECT DISTINCT m.movie_id, m.name 
					FROM Cinema..Screens s WITH(NOLOCK) 
					INNER JOIN Cinema..Movies m WITH(NOLOCK) ON s.movie_id = m.movie_id
					INNER JOIN Websites..SiteHouses sh WITH(NOLOCK) ON sh.house_id = s.house_id and sh.siteid = :siteid 
					WHERE s.showdate >= :date
					UNION ALL
					SELECT DISTINCT cs.movie_id,isnull(cs.title,m.name) as name 
				    FROM Websites..ComingSoon cs WITH(NOLOCK)
				    INNER JOIN Cinema..Movies m WITH(NOLOCK) ON cs.movie_id = m.movie_id
				    WHERE cs.release >= :release and cs.siteid = :siteid2
					ORDER BY m.name";
			$q = $db->prepare($sql);
			$q->execute(array(':siteid' => $site_id, ':siteid2' => $site_id, ':date' => date("n/j/Y", strtotime($date)), ':release' => date("n/j/Y", strtotime($date))));
			$movies = $q->fetchAll(PDO::FETCH_ASSOC);
		} catch (PDOException $e) {
			handle_exception($e);
		}
		
		return $movies;
	}
	
	/**
	 * Gets a two dimensional array of all movies coming soon 
	 * for the specified site based on FilmsXpress data.
	 * 
	 * @param $db
	 * @param $site_id
	 * @return Array $movies[numeric][key] a two dimensional array
	 * @see function 'sort_by_name'
	 */
	function fxp_get_coming_soon($db, $site_id, $choice_id) {
		$movies = array();
		
		//if coming soon, add showdate field
		if ($type == "cs") {
			$field = "";
			$join = "";
			$group = "";
		}
		
		try {
			$sql = "SELECT cs.movie_id, isnull(cs.release,m.release) as release, m.hiphotos, cs.posterImage,
				    isnull(cs.title,m.name) as name, ISNULL(cs.csMpaa,m.mpaa) as mpaa, m.videos, MIN(s.showdate) as showdate,
				    m.genre, m.genre2, m.genre3, m.runtime, 
				    CASE WHEN m.parent_id = '0' THEN cs.movie_id ELSE m.parent_id END as parent_id,
				    CASE WHEN cs.synopsis_type = 'Custom' THEN cs.custom_synopsis ELSE RTRIM(r.capsule) END AS capsule,
						cs.release_tbd
				    FROM Websites..ComingSoon cs WITH(NOLOCK)
				    JOIN Cinema..Movies m WITH(NOLOCK) on m.movie_id = cs.movie_id
				    LEFT OUTER JOIN Cinema..Reviews r WITH(NOLOCK) ON m.movie_id = r.movie_id AND r.sid = 
						CASE 
							WHEN cs.synopsis_type = 'none' OR 
								cs.synopsis_type = '' OR 
								cs.synopsis_type IS NULL 
							THEN 'HOME' 
							ELSE cs.synopsis_type 
						END 
				    LEFT OUTER JOIN Cinema..Screens s WITH(NOLOCK) on m.movie_id = s.movie_id and s.house_id in 
					 	(SELECT house_id from Websites..SiteHouses WITH(NOLOCK) where siteid = :site_id2)
				    WHERE CAST(isnull(isnull(cs.release,m.release),getdate()+1) as DateTime) > getdate()
				    and cs.SiteId = :site_id ";
				    
			//limit to movies woth a certain choice selected	    
			if ($choice_id != "") {
				$sql .= "and cs.csid in
							(SELECT csid from websites..sitechoiceselection WITH(NOLOCK)
							 WHERE siteid = $site_id and choiceid = $choice_id)";
			}
			
			//finish query
			$sql .=  " GROUP BY cs.movie_id, isnull(cs.release,m.release), m.hiphotos, isnull(cs.title,m.name), ISNULL(cs.csMpaa,m.mpaa), 
						m.videos, cs.posterImage, parent_id, m.genre, m.genre2, m.genre3, m.runtime,
						CASE WHEN cs.synopsis_type = 'Custom' THEN cs.custom_synopsis ELSE RTRIM(r.capsule) END, cs.release_tbd 
					   ORDER BY CAST(isnull(cs.release,m.release) as datetime), name";
			$q = $db->prepare($sql);
			$q->execute(array(':site_id' => $site_id, ':site_id2' => $site_id));
			$movies = $q->fetchAll(PDO::FETCH_ASSOC);

			for ($i = 0; $i < count($movies); $i++) {
				$movies[$i]['name'] = trim($movies[$i]['name']); // consistency
			}
		} catch (PDOException $e) {
			handle_exception($e);
		}
		return $movies;
	}

	
	/**
	 * Gets a two dimensional array of all movies coming soon 
	 * for the specified site and house based on FilmsXpress data.
	 * 
	 * @param $db
	 * @param $site_id
	 * @return Array $movies[numeric][key] a two dimensional array
	 * @see function 'sort_by_name'
	 */
	function fxp_get_house_coming_soon($db, $site_id, $house_id) {
		$movies = array();
		
		try {
			$q = $db->prepare("SELECT cs.movie_id, isnull(cs.release,mov.release) as release, mov.hiphotos, mov.mpaa,
							   isnull(cs.title,mov.name) as name, isnull(cs.url,mov.url) as url 
							   FROM Websites..ComingSoon cs WITH(NOLOCK)
							   JOIN Cinema..Movies mov WITH(NOLOCK) on mov.movie_id = cs.movie_id
							   WHERE CAST(isnull(isnull(cs.release,mov.release),getdate()+1) as DateTime) > getdate()
							   and cs.SiteId = :site_id and cs.csid in
							   		(SELECT csid FROM Websites..ComingSoonHouses where house_id = :house_id)
							   ORDER BY CAST(isnull(cs.release,mov.release) as datetime), name");
			$q->execute(array(':site_id' => $site_id,':house_id' => $house_id));
			$movies = $q->fetchAll(PDO::FETCH_ASSOC);
			for ($i = 0; $i < count($movies); $i++) {
				$movies[$i]['name'] = trim($movies[$i]['name']); // consistency
			}
		} catch (PDOException $e) {
			handle_exception($e);
		}
		return $movies;
	}
	
	
	/**
	 * Gets a two dimensional array of all pages for a website
	 * 
	 * @param $db
	 * @param $site_id
	 * @param $today
	 * @return Array $pages[numeric][key] a two dimensional array
	 */
	function fxp_get_created_pages($db, $site_id, $type, $date) {
		$pages = array();
		
		//was a type passed in?
		if ($type == "press") {
			$filter = "AND IsPress = 1 ";
		} elseif ($type == "event") {
			$filter = "AND IsEvent = 1 ";
		} elseif ($type == "news") {
			$filter = "AND IsNews = 1 ";
		} elseif ($type == "") {
			$filter = "AND (IsNews = 0 and IsEvent = 0 and IsPress = 0) ";
		} else {
			$filter = "";
		}
		
		try {
			$sql = "SELECT p.PageId, p.SiteHeadline, p.IsNews, p.IsPress, p.IsEvent   
					FROM websites..pages p WITH(NOLOCK)
					WHERE p.SiteId = :site_id $filter
					AND (cast(PageStart as datetime) <= :date or PageStart is null or PageStart = '')
					AND (cast(PageEnd as datetime) > :date2 or PageEnd is null or PageEnd = '')
					ORDER BY IsNews, IsEvent, IsPress, p.Priority, p.PageId";
			$q = $db->prepare($sql);
			$q->execute(array(':site_id' => $site_id, ':date' => $date, ':date2' => $date));
			$pages = $q->fetchAll(PDO::FETCH_ASSOC);
		} catch (PDOException $e) {
			handle_exception($e);
		}
		return $pages;
	}
	
	
	/**
	 * Outputs the page type
	 * 
	 * @param array $arr
	 *
	 * @return string $type
	 */
	function fxp_get_page_type($arr) {
		$type = "";
		
		//determine page type
		if ($arr["IsEvent"] == "1") {
			return "Event";
		} elseif ($arr["IsNews"] == "1") {
			return "News";
		} elseif ($arr["IsPress"] == "1") {
			return "Press";
		} else {
			return "Page";
		}
	}	
	
	/**
	 * Gets a array of details for a specific FXP page
	 * 
	 * @param $db
	 * @param $site_id
	 * @param $page_id
	 * @return Array $page[key] 
	 */
	function fxp_get_page_details($db, $site_id, $page_id) {
		$pages = array();
		
		try {
			$sql = "SELECT p.PageId, p.SiteHeadline, p.PageStart, p.PageEnd   
					FROM websites..pages p WITH(NOLOCK)
					WHERE p.SiteId = :site_id and p.PageId = :page_id";
			$q = $db->prepare($sql);
			$q->execute(array(':site_id' => $site_id, ':page_id' => $page_id));
			$page = $q->fetch(PDO::FETCH_ASSOC);
		} catch (PDOException $e) {
			handle_exception($e);
		}
		return $page;
	}
	
	
	/**
	 * Gets a two dimensional array of all coming soon houses for a movie
	 * for the specified site based on FilmsXpress data.
	 * 
	 * @param $db
	 * @param $site_id
	 * @param $movie_id
	 * @return Array $movies[numeric][key] a two dimensional array
	 * @see function 'sort_by_name'
	 */
	function fxp_get_movie_coming_soon($db, $site_id, $movie_id, $csid) {
		$movies = array();
		
		try {
			$q = $db->prepare("SELECT distinct ch.house_id, RTRIM(isnull(sh.name,ch.name)) as name
							   FROM Cinema..Houses ch WITH(NOLOCK)
							   INNER JOIN websites..sitehouses sh WITH(NOLOCK) ON ch.house_id = sh.house_id and sh.siteid = :site_id 
							   WHERE ch.house_id in
							   		(SELECT house_id FROM Websites..ComingSoonHouses where csid = :csid)
							   ORDER BY name");
			$q->execute(array(':site_id' => $site_id,':csid' => $csid));
			//print_r($q->errorInfo());
			$movies = $q->fetchAll(PDO::FETCH_ASSOC);
			for ($i = 0; $i < count($movies); $i++) {
				$movies[$i]['name'] = trim($movies[$i]['name']); // consistency
			}
		} catch (PDOException $e) {
			handle_exception($e);
		}
		return $movies;
	}


	/**
	 * Gets an array of house photo URLs for the specified house
	 * based on FilmsXpress data. There is a maximum of 2 photo URLs 
	 * possible.
	 * 
	 * @param $db
	 * @param $site_id
	 * @param $house_id
	 * @return Array $photos[numeric] an array of image URLs
	 * @see function 'fxp_build_house_photo_url'
	 */
	function fxp_get_house_photos($db, $site_id, $house_id) {
		$photos = array();
		try {
			$q = $db->prepare("
				SELECT PhotoUrl,PhotoUrl2 FROM websites..sitehouses WITH(NOLOCK) 
				WHERE SiteId = :site_id AND house_id = :house_id
			");
			$q->execute(array(':site_id' => $site_id, ':house_id' => $house_id));
			$r = $q->fetch(PDO::FETCH_ASSOC);
			if (!empty($r['PhotoUrl'])) {
				$photos[] = fxp_build_house_photo_url($site_id, $r['PhotoUrl']);
			}
			if (!empty($r['PhotoUrl2'])) {
				$photos[] = fxp_build_house_photo_url($site_id, $r['PhotoUrl2']);
			}
		} catch (PDOException $e) {
			handle_exception($e);
		}
		return $photos;
	}
	
	/**
	 * Gets a two dimensional array of carousel items (url, caption, image) 
	 * for the specified site based on from FilmsXpress data.
	 * 
	 * @param $db
	 * @param $site_id
	 * @return Array $items[numeric][key] a two dimensional array
	 * @see function 'fxp_build_carousel_photo_url'
	 */
	function fxp_get_carousel($db, $site_id, $category) {
		$items = array();
		
		if ($category != "") {
			$category_match = "and category = '$category' ";
		}
		
		try {
			$q = $db->prepare("SELECT * FROM websites..carousel WITH(NOLOCK) 
							   WHERE SiteID = :site_id AND (cast(expDate as datetime) >= :today or expDate is null or expDate = '') 
							   AND (cast(startDate as datetime) <= :today2 or startDate is null or startDate = '') $category_match
							   ORDER BY sort");
			$q->execute(array(':site_id' => $site_id, ':today' => date('m/d/Y'), ':today2' => date('m/d/Y')));
			$rs = $q->fetchAll(PDO::FETCH_ASSOC);
			foreach ($rs as $r) {
				$item = array();
				
				//fill in the $items array
				if (!empty($r['URL'])) {
					$item['url'] = $r['URL'];
				} else {
					$item['url'] = '#';
				}
				if ($r['targetURL'] == "1") {
					$item['target'] = "_blank";
				} else {
					$item['target'] = "_self";
				}
				if (!empty($r['imageTXT'])) {
					$item['caption'] = htmlspecialchars($r['imageTXT'], ENT_QUOTES);
				} else {
					$item['caption'] = '';
				}
				
				if (!empty($r['altTag'])) {
					$item['alt'] = htmlspecialchars($r['altTag'], ENT_QUOTES);
				} elseif ($item['caption'] != '') {
					$item['alt'] = $item['caption'];
				} else {
					$item['alt'] = 'Slider image';
				}
				
				if (stripos($r['largeImage'], '//') !== false){
					$item['image'] = $r['largeImage'];
				} else {
					$item['image'] = fxp_build_carousel_photo_url($site_id, $r['largeImage']);
				}
				$items[] = $item;
			}
		} catch (PDOException $e) {
			handle_exception($e);
		}
		return $items;
	}
	
	/**
	 * Gets an array of film info for special events
	 * 
	 * @param $db
	 * @param $site_id
	 * @param $choice_id 
	 * @param $date
	 * @return 2 dimmensional Array $events[key][value] with film info
	 */
	function fxp_get_special_events($db, $site_id, $choice_id, $date) {
		try {
			$q = $db->prepare("SELECT scs.choiceid, cs.csid, cs.movie_id, cs.release, rev.capsule, mov.flv_high,
								mov.name, mov.mpaa, mov.runtime, mov.actor1, mov.actor2, mov.actor3, mov.actor4, mov.hiphotos, cs.custom_text
								FROM Websites..ComingSoon cs WITH(NOLOCK)
								JOIN Cinema..Movies mov WITH(NOLOCK) on cs.movie_id = mov.movie_id
								LEFT OUTER JOIN Cinema..Reviews rev WITH(NOLOCK) ON rev.movie_id = cs.movie_id and rev.sid = 'SYSYN'
								LEFT OUTER JOIN Websites..SiteChoiceSelection scs WITH(NOLOCK) ON cs.csid = scs.csid and scs.choiceid = :choice_id 
								WHERE cs.siteid = :siteid and cs.csid in
								(SELECT csid FROM Websites..SiteChoiceSelection WHERE siteid = :siteid2)
								and cast(cs.release as datetime) >= :date
								ORDER BY scs.choiceid, cast(cs.release as datetime)");
			$q->execute(array(':siteid' => $site_id, ':siteid2' => $site_id, ':choice_id' => $choice_id, ':date' => $date));
			$events = $q->fetchAll();
		} catch (PDOException $e) {
			handle_exception($e);
		}
		
		return $events;
	}
	
	function getFacebookThumbs($facebook_page_owner, $facebook_album, $name) {

	 //use Facebook Graph API to retrieve albums' ID and count (no of images in album)
	 $string1 = @file_get_contents('https://graph.facebook.com/'.$facebook_page_owner.'/albums?fields=id,count');

	 //the Json file with the data contains the word "count" which is a reserved word in PHP, so I replaced it with "countx" (I know- very imaginative)
	 $string = str_replace ("count", "countx", $string1);

	 //decoding the Json feed
	 $jdata = json_decode($string);


	 /* NEW WAY! - SPECIFIC ALBUM ID PASSED TO FUNCTION */	
	 	
	 //get the information about this album
	// $string2 = @file_get_contents('https://graph.facebook.com/fql?q=SELECT%20name,%20created%20FROM%20album%20WHERE%20owner='.$facebook_page_owner.'%20and%20object_id='.$facebook_album.'');
	 //$adata = json_decode($string2);
	 $albumname = $name; 
     
	 //output the cover thumbnail and link to full facebook album
	 echo " <div class='FB_pic_container'>
				<a href='../../gallery?albumid=".$facebook_album."&albumname=".$albumname."' class='various fbGallery' data-fancybox-type='iframe' width='800px' height='600px'>
			 	<div style='text-align: center'>
			 		<img src='/img/vGallery_icon.png'/>
					
			 	</div></a>
			 </div>";
			 }

function getTheaterPhotos($db, $site_id, $album_id = null) {

    if(!is_null($album_id)){
        try {
            $q = $db->prepare("
                SELECT
                  c.*,
                  cc.description as category_name
                FROM Websites..Carousel c WITH(NOLOCK)
                LEFT OUTER JOIN Websites..CarouselCategories cc WITH(NOLOCK) ON c.category = cc.name AND c.SiteId = cc.SiteId
                WHERE
                    c.SiteID = :site_id
                    AND cc.category_id = :album_id
                ORDER BY c.category, c.sort");

            $q->execute(array(':site_id' => $site_id, ':album_id' => $album_id));
            $photos = $q->fetchAll(PDO::FETCH_ASSOC);

        } catch (PDOException $e) {
            handle_exception($e);
        }

        return $photos;
    }else{
        return 'error';
    }
}

/**
 * Builds attributes from comments string
 * 
 * @param $house_id
 * @param $comment
 * 
 * @return string[]
 */
function build_attributes($house_id, $comment = '') {
	$comment = strtolower(trim($comment));
	$comment = str_ireplace('xtreme_mob;', '', $comment);
	$comment = str_ireplace('xtreme_mob', '', $comment);

	if (stripos($allow_passes, 'n') !== false) {
		$comment = str_ireplace('no passes;', '', $comment);
	}

	// janky comment replacements
	$comment = str_ireplace('Extreme; Extreme', 'Extreme', $comment); // TODO: FIX
	$comment = str_ireplace('upper;', '', $comment);
	$comment = str_ireplace('upper', '', $comment);
	
	if (stripos($comment, 'lower') !== false) {
		$comment = str_ireplace('21+ loveseat vip recliners', 'reserved recliners', $comment);
		if ($house_id == '24088') {
			$comment = str_ireplace('loveseat vip recliners', 'reserved recliners', $comment);
		}
		if ($house_id == '11516') {
			$comment = str_ireplace('loveseat vip recliners', 'reserved', $comment);
		}
	}
	
	$comment = str_ireplace('lower;', '', $comment);
	$comment = str_ireplace('lower', '', $comment);
	if ($house_id == '41597') {
		$comment = str_ireplace('stadium;', '', $comment);
		$comment = str_ireplace('stadium', '', $comment);
	}
	// Dalton wants extreme and reserved on one line for Delray
	if (($house_id == '29923') && (stripos($comment, 'extreme') !== false && stripos($comment, 'reserved') !== false)) {
		$comment = str_replace('reserved', '', $comment);
		$comment = str_replace('extreme', 'extreme reserved', $comment);
	} 

	if ($house_id == '24088' && (stripos($comment, 'loveseat vip recliners') === false)) {
		$comment = str_replace('21 & up after 4pm;', '', $comment);
	}
	
	if ($house_id == '24088' && (stripos($comment, 'loveseat vip recliners') !== false)) {
		$comment = str_replace('recline; reserved;', 'Chatterbox Dine-In;', $comment);
		if ($movie_id == '189712') {
			$comment = str_replace('21 & up after 4pm;', '', $comment);
		}
	}
	if ($house_id == '11516' && (stripos($comment, 'loveseat vip recliners') !== false)) {
		$comment = str_replace('loveseat vip recliners;', 'Loveseat VIP Recliners; Dine-In Theaters;', $comment);
		$comment = str_replace('reserved;', '', $comment);
	}

	// format comment
	$comment_array = explode(';', $comment);
	foreach ($comment_array as $key => $comment) {
		$comment_array[$key] = trim($comment);
	}

	if (array_search('reserved', $comment_array) !== false && (array_search('imax reserved seating', $comment_array) !== false)) {
		unset($comment_array[array_search('reserved', $comment_array)]);
	}
	
	if (array_search('extreme reserved seating', $comment_array) !== false) {
		if (array_search('reserved', $comment_array) !== false) {
			unset($comment_array[array_search('reserved', $comment_array)]);
		}
	}

	if ($movie_id == '313587') {
		$comment_array[] = 'private movie party';
	}

	if ($movie_id == '62418') {
		$comment_array[] = 'private streaming party';
	}

	foreach ($comment_array as $key => $comment) {
		
		switch ($comment) {
			case 'premier 21+ reserved seating & general seating':
				$comment_array[$key] .= ' - SOME SHOWTIMES DO NOT HAVE PREMIER 21+ AVAILABLE';
				break;
			
			case 'dolby atmos extreme':
				$comment_array[$key] .= ' RESERVED LUXURY RECLINERS';
				break;

			case 'recline':
				if ($house_id == '29923' || $house_id == '41597') {
					$comment_array[$key] = 'reserved seating';
				} elseif ($house_id == '24088') {
					$comment_array[$key] = 'reserved recliners';
				} else {
					$comment_array[$key] = 'reserved luxury recliners';
				}
				break;
				
			case 'reserved':
				if ($house_id == '29923' || $house_id == '41597' || $house_id == '11516') {
					$comment_array[$key] = 'reserved seating';
				} elseif ($house_id == '24088') {
					$comment_array[$key] = 'reserved recliners';
				} else {
					$comment_array[$key] = 'reserved luxury recliners';
				}
				break;

			case 'extreme reserved':
				$comment_array[$key] = 'extreme reserved seating';
				break;
				
			case 'stadium':
				if(in_array($house_id, array('2537','26277', '22143', '29923'))) {
					unset($comment_array[$key]);
				}
				break;
			
			case 'private watch party':
				$comment_array[$key] = '$149 Private Watch Party';
				break;

			case 'private movie party':
				$people = ($house_id == '24088')  ? '10' : '20';
				$comment_array[$key] = '$149 Private Watch Party<br/>Up to ' . $people . ' People';
				break;

			case 'private streaming party':
				$people = ($house_id == '24088')  ? '10' : '20';
				$comment_array[$key] = '$99 Private Streaming Party<br/>Up to ' . $people . ' People';
				break;
		}

		$comment_array[$key] = trim($comment_array[$key]);
	}

	$comment_array = array_unique($comment_array);
	$comment = implode('<br/>', $comment_array);

	if ($comment == '') {
		$comment = 'General Seating';
	}

	return $comment;
}

/**
 * Build and combine showtimes rows
 * 
 * @param $house_id
 * @param $raw_data
 * @param $soldouts
 * @return mixed[]
 */
function build_showtime_rows($house_id, $raw_data, $soldouts = [], $ticketing = true) {
	$data = array();
	$cur_time = date('H:i', strtotime("now"));
	$cur_date = date('mdY', strtotime("today"));

	foreach ($raw_data as $row) {
		$key = array_search($row['movie_id'], array_column($data, 'movie_id'));
		if ($key === false) {
			$data[] = $row;
			$key = count($data) - 1;
			$data[$key]['showtimes'] = array();
		}

		// Remove stadium from Ridge comments
		if ($house_id == '22143' && stripos($row['comment'], 'stadium') !== false) {
			$split_comment = explode(';', $row['comment']);
			foreach ($split_comment as $split_comment_key => $split_comment_line) {
				if (stripos($split_comment_line, 'stadium') !== false) {
					unset($split_comment[$split_comment_key]);
				}
			}
			$row['comment'] = implode('; ', $split_comment);
		}

		$row['comment'] = trim($row['comment']);
		
		$showtimes_key = array_search($row['comment'], array_column($data[$key]['showtimes'], 'comment'));
		
		// Certain strings that are the same are returning differently?
		if ($showtimes_key === false) {
			foreach ($data[$key]['showtimes'] as $k => $v) {
				$a = preg_replace("/[^A-Z]+/", "", $v['comment']);
				$b = preg_replace("/[^A-Z]+/", "", $row['comment']);
				if ($a == $b) {
					$showtimes_key = $k;
				} 
			}
		}
		
		if ($showtimes_key === false) {
			$data[$key]['showtimes'][] = array(
				'comment' => trim($row['comment']), 
				'allowpass' => $row['allowpass'],
				'times' => array()
			);
			$showtimes_key = count($data[$key]['showtimes']) - 1;
		}


		$showdate = date('mdY', strtotime($row['showdate']));
		for ($i = 1; $i < 49; $i++) {
			if (trim($row["time$i"]) == '') {
				continue;
			}
			$time_display = build_showtime($row['time' . $i], $row['mer' . $i]);
			$time_url = build_showtime_url($house_id, $row['movie_id'], $row['showdate'], $row['time' . $i], $row['mer' . $i], $row['comment']);
			
			//we need to figure out if the time is past 'Now'
			$showtime = build_military_time($row["time$i"], $row["mer$i"]);	
			$time_html = '';
			if (
				$ticketing && 
				!isSoldOut($soldouts, $house_id, $row['movie_id'], $row['showdate'], $showtime, $row['comment']) && 
				($cur_date < $showdate || ($cur_date == $showdate && $cur_time < $showtime))
			) {
				$time_html = '
					<div class="view now">
						<a href="'.$time_url.'" target="_blank" class="time">'.$time_display.'</a>
						<div class="mask"></div>
						<div class="hover"><a href="'.$time_url.'" target="_blank"  class="info"></a></div>
					</div>
				';
			} else {
				$time_html = '<span class="showtime_expired">'.$time_display.'</span>';
			}
			
			$data[$key]['showtimes'][$showtimes_key]['times'][] = array(
				'html' => $time_html,
				'sort' => $showtime,
			);

		}
	}

	// Split private watch party showtimes 
	foreach ($data as $key => $row) {
		foreach ($row['showtimes'] as $showtimes_key => $showtimes_row) {
			if (stripos($showtimes_row['comment'], 'private watch party') !== false) {
				$new_row = $row;
				$new_row['name'] = $new_row['name'] . ' - Private Watch Party';
				$new_row['showtimes'] = array($showtimes_row);
				unset($data[$key]['showtimes'][$showtimes_key]);
				$data[] = $new_row;
			}
		}
	}

	// Duplicate upper/lower movies for some reason
	foreach ($data as $key => $row) {
		foreach ($row['showtimes'] as $showtimes_key => $showtimes_row) {
			if (stripos($showtimes_row['comment'], 'upper') !== false) {
				$new_row = $showtimes_row;
				$new_row['comment'] = str_ireplace('upper;', 'lower;', $new_row['comment']);
				$new_row['comment'] = str_ireplace('upper', 'lower', $new_row['comment']);
				$data[$key]['showtimes'][] = $new_row;
			}
		}
	}

	// Sort by release desc, name asc
	usort($data, function($a, $b) {
		$release_cmp = strcmp($a['raw_release'], $b['raw_release']);
		if ($release_cmp != 0) {
			return -($release_cmp);
		}
		return strcmp($a['name'], $b['name']);
	});

	return $data;
}
	
?>